@@ -9,7 +9,9 @@
  */
 
 // update message version - always use a string to avoid localized floats!
-$updateVersion = "50.1";
+use dokuwiki\Extension\Event;
+
+$updateVersion = "53";
 
 //  xdebug_start_profiling();
 
@@ -70,17 +72,21 @@ if($DATE_AT) {
 
 //check for existing $REV related to $DATE_AT
 if($DATE_AT) {
-    $pagelog = new PageChangeLog($ID);
+    $pagelog = new \dokuwiki\ChangeLog\PageChangeLog($ID);
     $rev_t = $pagelog->getLastRevisionAt($DATE_AT);
     if($rev_t === '') { //current revision
         $REV = null;
         $DATE_AT = null;
     } else if ($rev_t === false) { //page did not exist
         $rev_n = $pagelog->getRelativeRevision($DATE_AT,+1);
-        msg(sprintf($lang['page_nonexist_rev'],
-            strftime($conf['dformat'],$DATE_AT),
-            wl($ID, array('rev' => $rev_n)),
-            strftime($conf['dformat'],$rev_n)));
+        msg(
+            sprintf(
+                $lang['page_nonexist_rev'],
+                dformat($DATE_AT),
+                wl($ID, array('rev' => $rev_n)),
+                dformat($rev_n)
+            )
+        );
         $REV = $DATE_AT; //will result in a page not exists message
     } else {
         $REV = $rev_t;
@@ -111,7 +117,7 @@ if($conf['breadcrumbs']) breadcrumbs();
 checkUpdateMessages();
 
 $tmp = array(); // No event data
-trigger_event('DOKUWIKI_STARTED', $tmp);
+Event::createAndTrigger('DOKUWIKI_STARTED', $tmp);
 
 //close session
 session_write_close();
@@ -120,6 +126,6 @@ session_write_close();
 act_dispatch();
 
 $tmp = array(); // No event data
-trigger_event('DOKUWIKI_DONE', $tmp);
+Event::createAndTrigger('DOKUWIKI_DONE', $tmp);
 
 //  xdebug_dump_function_profile(1);
