@@ -1,12 +1,13 @@
 <?php
+
 namespace dokuwiki\Form;
 
 /**
  * Class TextareaElement
  * @package dokuwiki\Form
  */
-class TextareaElement extends InputElement {
-
+class TextareaElement extends InputElement
+{
     /**
      * @var string the actual text within the area
      */
@@ -16,7 +17,8 @@ class TextareaElement extends InputElement {
      * @param string $name The name of this form element
      * @param string $label The label text for this element
      */
-    public function __construct($name, $label) {
+    public function __construct($name, $label)
+    {
         parent::__construct('textarea', $name, $label);
         $this->attr('dir', 'auto');
     }
@@ -29,8 +31,9 @@ class TextareaElement extends InputElement {
      * @param null|string $value
      * @return string|$this
      */
-    public function val($value = null) {
-        if($value !== null) {
+    public function val($value = null)
+    {
+        if ($value !== null) {
             $this->text = cleanText($value);
             return $this;
         }
@@ -42,10 +45,11 @@ class TextareaElement extends InputElement {
      *
      * @return string
      */
-    protected function mainElementHTML() {
-        if($this->useInput) $this->prefillInput();
+    protected function mainElementHTML()
+    {
+        if ($this->useInput) $this->prefillInput();
         return '<textarea ' . buildAttributes($this->attrs()) . '>' .
-        formText($this->val()) . '</textarea>';
+            formText($this->val()) . '</textarea>';
     }
 
 }
