@@ -5,7 +5,9 @@
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
-if(!defined('DOKU_INC')) die('meh.');
+
+use dokuwiki\HTTP\DokuHTTPClient;
+use dokuwiki\Logger;
 
 if(!defined('DOKU_MESSAGEURL')){
     if(in_array('ssl', stream_get_transports())) {
@@ -34,7 +36,7 @@ function checkUpdateMessages(){
     // check if new messages needs to be fetched
     if($lm < time()-(60*60*24) || $lm < @filemtime(DOKU_INC.DOKU_SCRIPT)){
         @touch($cf);
-        dbglog("checkUpdateMessages(): downloading messages to ".$cf.($is_http?' (without SSL)':' (with SSL)'));
+        Logger::debug("checkUpdateMessages(): downloading messages to ".$cf.($is_http?' (without SSL)':' (with SSL)'));
         $http = new DokuHTTPClient();
         $http->timeout = 12;
         $resp = $http->get(DOKU_MESSAGEURL.$updateVersion);
@@ -43,10 +45,10 @@ function checkUpdateMessages(){
             // or it looks like one of our messages, not WiFi login or other interposed response
             io_saveFile($cf,$resp);
         } else {
-            dbglog("checkUpdateMessages(): unexpected HTTP response received");
+            Logger::debug("checkUpdateMessages(): unexpected HTTP response received", $http->error);
         }
     }else{
-        dbglog("checkUpdateMessages(): messages up to date");
+        Logger::debug("checkUpdateMessages(): messages up to date");
     }
 
     $data = io_readFile($cf);
@@ -74,21 +76,29 @@ function getVersionData(){
         $version['type'] = 'Git';
         $version['date'] = 'unknown';
 
-        $inventory = DOKU_INC.'.git/logs/HEAD';
-        if(is_file($inventory)){
-            $sz   = filesize($inventory);
-            $seek = max(0,$sz-2000); // read from back of the file
-            $fh   = fopen($inventory,'rb');
-            fseek($fh,$seek);
-            $chunk = fread($fh,2000);
-            fclose($fh);
-            $chunk = trim($chunk);
-            $chunk = @array_pop(explode("\n",$chunk));   //last log line
-            $chunk = @array_shift(explode("\t",$chunk)); //strip commit msg
-            $chunk = explode(" ",$chunk);
-            array_pop($chunk); //strip timezone
-            $date = date('Y-m-d',array_pop($chunk));
-            if($date) $version['date'] = $date;
+        if ($date = shell_exec("git log -1 --pretty=format:'%cd' --date=short")) {
+            $version['date'] = hsc($date);
+        } else if (file_exists(DOKU_INC . '.git/HEAD')) {
+            // we cannot use git on the shell -- let's do it manually!
+            $headCommit = trim(file_get_contents(DOKU_INC . '.git/HEAD'));
+            if (strpos($headCommit, 'ref: ') === 0) {
+                // it is something like `ref: refs/heads/master`
+                $pathToHead = substr($headCommit, 5);
+                $headCommit = trim(file_get_contents(DOKU_INC . '.git/' . $pathToHead));
+            }
+            $subDir = substr($headCommit, 0, 2);
+            $fileName = substr($headCommit, 2);
+            $gitCommitObject = DOKU_INC . ".git/objects/$subDir/$fileName";
+            if (file_exists($gitCommitObject) && function_exists('zlib_decode')) {
+                $commit = zlib_decode(file_get_contents($gitCommitObject));
+                $committerLine = explode("\n", $commit)[3];
+                $committerData = explode(' ', $committerLine);
+                end($committerData);
+                $ts = prev($committerData);
+                if ($ts && $date = date('Y-m-d', $ts)) {
+                    $version['date'] = $date;
+                }
+            }
         }
     }else{
         global $updateVersion;
@@ -122,27 +132,32 @@ function check(){
     if ($INFO['isadmin'] || $INFO['ismanager']){
         msg('DokuWiki version: '.getVersion(),1);
 
-        if(version_compare(phpversion(),'5.6.0','<')){
-            msg('Your PHP version is too old ('.phpversion().' vs. 5.6.0+ needed)',-1);
+        if(version_compare(phpversion(),'7.2.0','<')){
+            msg('Your PHP version is too old ('.phpversion().' vs. 7.2+ needed)',-1);
         }else{
             msg('PHP version '.phpversion(),1);
         }
     } else {
-        if(version_compare(phpversion(),'5.6.0','<')){
+        if(version_compare(phpversion(),'7.2.0','<')){
             msg('Your PHP version is too old',-1);
         }
     }
 
     $mem = (int) php_to_byte(ini_get('memory_limit'));
     if($mem){
-        if($mem < 16777216){
-            msg('PHP is limited to less than 16MB RAM ('.$mem.' bytes). Increase memory_limit in php.ini',-1);
-        }elseif($mem < 20971520){
-            msg('PHP is limited to less than 20MB RAM ('.$mem.' bytes), you might encounter problems with bigger pages. Increase memory_limit in php.ini',-1);
-        }elseif($mem < 33554432){
-            msg('PHP is limited to less than 32MB RAM ('.$mem.' bytes), but that should be enough in most cases. If not, increase memory_limit in php.ini',0);
-        }else{
-            msg('More than 32MB RAM ('.$mem.' bytes) available.',1);
+        if ($mem === -1) {
+            msg('PHP memory is unlimited', 1);
+        } else if ($mem < 16777216) {
+            msg('PHP is limited to less than 16MB RAM (' . filesize_h($mem) . ').
+            Increase memory_limit in php.ini', -1);
+        } else if ($mem < 20971520) {
+            msg('PHP is limited to less than 20MB RAM (' . filesize_h($mem) . '),
+                you might encounter problems with bigger pages. Increase memory_limit in php.ini', -1);
+        } else if ($mem < 33554432) {
+            msg('PHP is limited to less than 32MB RAM (' . filesize_h($mem) . '),
+                but that should be enough in most cases. If not, increase memory_limit in php.ini', 0);
+        } else {
+            msg('More than 32MB RAM (' . filesize_h($mem) . ') available.', 1);
         }
     }
 
@@ -208,7 +223,8 @@ function check(){
     if(!$loc){
         msg('No valid locale is set for your PHP setup. You should fix this',-1);
     }elseif(stripos($loc,'utf') === false){
-        msg('Your locale <code>'.hsc($loc).'</code> seems not to be a UTF-8 locale, you should fix this if you encounter problems.',0);
+        msg('Your locale <code>'.hsc($loc).'</code> seems not to be a UTF-8 locale,
+             you should fix this if you encounter problems.',0);
     }else{
         msg('Valid locale '.hsc($loc).' found.', 1);
     }
@@ -221,23 +237,25 @@ function check(){
 
     if($INFO['userinfo']['name']){
         msg('You are currently logged in as '.$INPUT->server->str('REMOTE_USER').' ('.$INFO['userinfo']['name'].')',0);
-        msg('You are part of the groups '.join($INFO['userinfo']['grps'],', '),0);
+        msg('You are part of the groups '.implode(', ', $INFO['userinfo']['grps']),0);
     }else{
         msg('You are currently not logged in',0);
     }
 
     msg('Your current permission for this page is '.$INFO['perm'],0);
 
-    if(is_writable($INFO['filepath'])){
-        msg('The current page is writable by the webserver',0);
-    }else{
-        msg('The current page is not writable by the webserver',0);
+    if (file_exists($INFO['filepath']) && is_writable($INFO['filepath'])) {
+        msg('The current page is writable by the webserver', 1);
+    } elseif (!file_exists($INFO['filepath']) && is_writable(dirname($INFO['filepath']))) {
+        msg('The current page can be created by the webserver', 1);
+    } else {
+        msg('The current page is not writable by the webserver', -1);
     }
 
-    if($INFO['writable']){
-        msg('The current page is writable by you',0);
-    }else{
-        msg('The current page is not writable by you',0);
+    if ($INFO['writable']) {
+        msg('The current page is writable by you', 1);
+    } else {
+        msg('The current page is not writable by you', -1);
     }
 
     // Check for corrupted search index
@@ -288,38 +306,23 @@ function check(){
         if(abs($diff) < 4) {
             msg("Server time seems to be okay. Diff: {$diff}s", 1);
         } else {
-            msg("Your server's clock seems to be out of sync! Consider configuring a sync with a NTP server.  Diff: {$diff}s");
+            msg("Your server's clock seems to be out of sync!
+                 Consider configuring a sync with a NTP server.  Diff: {$diff}s");
         }
     }
 
 }
 
 /**
- * print a message
+ * Display a message to the user
  *
  * If HTTP headers were not sent yet the message is added
  * to the global message array else it's printed directly
  * using html_msgarea()
  *
+ * Triggers INFOUTIL_MSG_SHOW
  *
- * Levels can be:
- *
- * -1 error
- *  0 info
- *  1 success
- *
- * @author Andreas Gohr <andi@splitbrain.org>
- * @see    html_msgarea
- */
-
-define('MSG_PUBLIC', 0);
-define('MSG_USERS_ONLY', 1);
-define('MSG_MANAGERS_ONLY',2);
-define('MSG_ADMINS_ONLY',4);
-
-/**
- * Display a message to the user
- *
+ * @see    html_msgarea()
  * @param string $message
  * @param int    $lvl   -1 = error, 0 = info, 1 = success, 2 = notify
  * @param string $line  line number
@@ -328,24 +331,42 @@ define('MSG_ADMINS_ONLY',4);
  */
 function msg($message,$lvl=0,$line='',$file='',$allow=MSG_PUBLIC){
     global $MSG, $MSG_shown;
-    $errors = array();
-    $errors[-1] = 'error';
-    $errors[0]  = 'info';
-    $errors[1]  = 'success';
-    $errors[2]  = 'notify';
+    static $errors = [
+        -1 => 'error',
+        0 => 'info',
+        1 => 'success',
+        2 => 'notify',
+    ];
 
-    if($line || $file) $message.=' ['.utf8_basename($file).':'.$line.']';
+    $msgdata = [
+        'msg' => $message,
+        'lvl' => $errors[$lvl],
+        'allow' => $allow,
+        'line' => $line,
+        'file' => $file,
+    ];
 
-    if(!isset($MSG)) $MSG = array();
-    $MSG[]=array('lvl' => $errors[$lvl], 'msg' => $message, 'allow' => $allow);
-    if(isset($MSG_shown) || headers_sent()){
-        if(function_exists('html_msgarea')){
-            html_msgarea();
-        }else{
-            print "ERROR($lvl) $message";
+    $evt = new \dokuwiki\Extension\Event('INFOUTIL_MSG_SHOW', $msgdata);
+    if ($evt->advise_before()) {
+        /* Show msg normally - event could suppress message show */
+        if($msgdata['line'] || $msgdata['file']) {
+            $basename = \dokuwiki\Utf8\PhpString::basename($msgdata['file']);
+            $msgdata['msg'] .=' ['.$basename.':'.$msgdata['line'].']';
+        }
+
+        if(!isset($MSG)) $MSG = array();
+        $MSG[] = $msgdata;
+        if(isset($MSG_shown) || headers_sent()){
+            if(function_exists('html_msgarea')){
+                html_msgarea();
+            }else{
+                print "ERROR(".$msgdata['lvl'].") ".$msgdata['msg']."\n";
+            }
+            unset($GLOBALS['MSG']);
         }
-        unset($GLOBALS['MSG']);
     }
+    $evt->advise_after();
+    unset($evt);
 }
 /**
  * Determine whether the current user is allowed to view the message
@@ -378,7 +399,8 @@ function info_msg_allowed($msg){
             return $INFO['isadmin'];
 
         default:
-            trigger_error('invalid msg allow restriction.  msg="'.$msg['msg'].'" allow='.$msg['allow'].'"', E_USER_WARNING);
+            trigger_error('invalid msg allow restriction.  msg="'.$msg['msg'].'" allow='.$msg['allow'].'"',
+                          E_USER_WARNING);
             return $INFO['isadmin'];
     }
 
@@ -408,59 +430,35 @@ function dbg($msg,$hidden=false){
 }
 
 /**
- * Print info to a log file
+ * Print info to debug log file
  *
  * @author Andreas Gohr <andi@splitbrain.org>
- *
+ * @deprecated 2020-08-13
  * @param string $msg
  * @param string $header
  */
 function dbglog($msg,$header=''){
-    global $conf;
-    /* @var Input $INPUT */
-    global $INPUT;
+    dbg_deprecated('\\dokuwiki\\Logger');
 
-    // The debug log isn't automatically cleaned thus only write it when
-    // debugging has been enabled by the user.
-    if($conf['allowdebug'] !== 1) return;
-    if(is_object($msg) || is_array($msg)){
-        $msg = print_r($msg,true);
+    // was the msg as single line string? use it as header
+    if($header === '' && is_string($msg) && strpos($msg, "\n") === false) {
+        $header = $msg;
+        $msg = '';
     }
 
-    if($header) $msg = "$header\n$msg";
-
-    $file = $conf['cachedir'].'/debug.log';
-    $fh = fopen($file,'a');
-    if($fh){
-        fwrite($fh,date('H:i:s ').$INPUT->server->str('REMOTE_ADDR').': '.$msg."\n");
-        fclose($fh);
-    }
+    Logger::getInstance(Logger::LOG_DEBUG)->log(
+        $header, $msg
+    );
 }
 
 /**
  * Log accesses to deprecated fucntions to the debug log
  *
  * @param string $alternative The function or method that should be used instead
+ * @triggers INFO_DEPRECATION_LOG
  */
 function dbg_deprecated($alternative = '') {
-    global $conf;
-    if(!$conf['allowdebug']) return;
-
-    $backtrace = debug_backtrace();
-    array_shift($backtrace);
-    $self = array_shift($backtrace);
-    $call = array_shift($backtrace);
-
-    $called = trim($self['class'].'::'.$self['function'].'()', ':');
-    $caller = trim($call['class'].'::'.$call['function'].'()', ':');
-
-    $msg = $called.' is deprecated. It was called from ';
-    $msg .= $caller.' in '.$call['file'].':'.$call['line'];
-    if($alternative) {
-        $msg .= ' '.$alternative.' should be used instead!';
-    }
-
-    dbglog($msg);
+    \dokuwiki\Debug\DebugHelper::dbgDeprecatedFunction($alternative, 2);
 }
 
 /**
