@@ -6,7 +6,8 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-if(!defined('DOKU_INC')) die('meh.');
+use dokuwiki\HTTP\DokuHTTPClient;
+use dokuwiki\Extension\Event;
 
 /**
  * Removes empty directories
@@ -16,7 +17,6 @@ if(!defined('DOKU_INC')) die('meh.');
  * $data[0]    ns: The colon separated namespace path minus the trailing page name.
  * $data[1]    ns_type: 'pages' or 'media' namespace tree.
  *
- * @todo use safemode hack
  * @param string $id      - a pageid, the namespace of that id will be tried to deleted
  * @param string $basedir - the config name of the type to delete (datadir or mediadir usally)
  * @return bool - true if at least one namespace was deleted
@@ -40,7 +40,7 @@ function io_sweepNS($id,$basedir='datadir'){
             if ($ns_type!==false) {
                 $data = array($id, $ns_type);
                 $delone = true; // we deleted at least one dir
-                trigger_event('IO_NAMESPACE_DELETED', $data);
+                Event::createAndTrigger('IO_NAMESPACE_DELETED', $data);
             }
         } else { return $delone; }
     }
@@ -70,7 +70,7 @@ function io_sweepNS($id,$basedir='datadir'){
 function io_readWikiPage($file, $id, $rev=false) {
     if (empty($rev)) { $rev = false; }
     $data = array(array($file, true), getNS($id), noNS($id), $rev);
-    return trigger_event('IO_WIKIPAGE_READ', $data, '_io_readWikiPage_action', false);
+    return Event::createAndTrigger('IO_WIKIPAGE_READ', $data, '_io_readWikiPage_action', false);
 }
 
 /**
@@ -190,7 +190,7 @@ function io_writeWikiPage($file, $content, $id, $rev=false) {
     if (empty($rev)) { $rev = false; }
     if ($rev===false) { io_createNamespace($id); } // create namespaces as needed
     $data = array(array($file, $content, false), getNS($id), noNS($id), $rev);
-    return trigger_event('IO_WIKIPAGE_WRITE', $data, '_io_writeWikiPage_action', false);
+    return Event::createAndTrigger('IO_WIKIPAGE_WRITE', $data, '_io_writeWikiPage_action', false);
 }
 
 /**
@@ -202,7 +202,12 @@ function io_writeWikiPage($file, $content, $id, $rev=false) {
  */
 function _io_writeWikiPage_action($data) {
     if (is_array($data) && is_array($data[0]) && count($data[0])===3) {
-        return call_user_func_array('io_saveFile', $data[0]);
+        $ok = call_user_func_array('io_saveFile', $data[0]);
+        // for attic files make sure the file has the mtime of the revision
+        if($ok && is_int($data[3]) && $data[3] > 0) {
+            @touch($data[0][0], $data[3]);
+        }
+        return $ok;
     } else {
         return false; //callback error
     }
@@ -247,7 +252,7 @@ function _io_saveFile($file, $content, $append) {
         fclose($fh);
     }
 
-    if(!$fileexists and !empty($conf['fperm'])) chmod($file, $conf['fperm']);
+    if(!$fileexists and $conf['fperm']) chmod($file, $conf['fperm']);
     return true;
 }
 
@@ -334,7 +339,8 @@ function io_replaceInFile($file, $oldline, $newline, $regex=false, $maxlines=0)
     if ($maxlines > 0) {
         $count = 0;
         $matched = 0;
-        while (($count < $maxlines) && (list($i,$line) = each($lines))) {
+        foreach($lines as $i => $line) {
+            if($count >= $maxlines) break;
             // $matched will be set to 0|1 depending on whether pattern is matched and line replaced
             $lines[$i] = preg_replace($pattern, $replace, $line, -1, $matched);
             if ($matched) $count++;
@@ -394,8 +400,6 @@ function io_deleteFromFile($file,$badline,$regex=false){
  */
 function io_lock($file){
     global $conf;
-    // no locking if safemode hack
-    if($conf['safemodehack']) return;
 
     $lockDir = $conf['lockdir'].'/'.md5($file);
     @ignore_user_abort(1);
@@ -404,9 +408,9 @@ function io_lock($file){
     do {
         //waited longer than 3 seconds? -> stale lock
         if ((time() - $timeStart) > 3) break;
-        $locked = @mkdir($lockDir, $conf['dmode']);
+        $locked = @mkdir($lockDir);
         if($locked){
-            if(!empty($conf['dperm'])) chmod($lockDir, $conf['dperm']);
+            if($conf['dperm']) chmod($lockDir, $conf['dperm']);
             break;
         }
         usleep(50);
@@ -422,8 +426,6 @@ function io_lock($file){
  */
 function io_unlock($file){
     global $conf;
-    // no locking if safemode hack
-    if($conf['safemodehack']) return;
 
     $lockDir = $conf['lockdir'].'/'.md5($file);
     @rmdir($lockDir);
@@ -468,7 +470,7 @@ function io_createNamespace($id, $ns_type='pages') {
     $missing = array_reverse($missing); // inside out
     foreach ($missing as $ns) {
         $data = array($ns, $ns_type);
-        trigger_event('IO_NAMESPACE_CREATED', $data);
+        Event::createAndTrigger('IO_NAMESPACE_CREATED', $data);
     }
 }
 
@@ -502,14 +504,9 @@ function io_mkdir_p($target){
     if (file_exists($target) && !is_dir($target)) return 0;
     //recursion
     if (io_mkdir_p(substr($target,0,strrpos($target,'/')))){
-        if($conf['safemodehack']){
-            $dir = preg_replace('/^'.preg_quote(fullpath($conf['ftp']['root']),'/').'/','', $target);
-            return io_mkdir_ftp($dir);
-        }else{
-            $ret = @mkdir($target,$conf['dmode']); // crawl back up & create dir tree
-            if($ret && !empty($conf['dperm'])) chmod($target, $conf['dperm']);
-            return $ret;
-        }
+        $ret = @mkdir($target); // crawl back up & create dir tree
+        if($ret && !empty($conf['dperm'])) chmod($target, $conf['dperm']);
+        return $ret;
     }
     return 0;
 }
@@ -564,44 +561,6 @@ function io_rmdir($path, $removefiles = false) {
     return false;
 }
 
-/**
- * Creates a directory using FTP
- *
- * This is used when the safemode workaround is enabled
- *
- * @author <andi@splitbrain.org>
- *
- * @param string $dir name of the new directory
- * @return false|string
- */
-function io_mkdir_ftp($dir){
-    global $conf;
-
-    if(!function_exists('ftp_connect')){
-        msg("FTP support not found - safemode workaround not usable",-1);
-        return false;
-    }
-
-    $conn = @ftp_connect($conf['ftp']['host'],$conf['ftp']['port'],10);
-    if(!$conn){
-        msg("FTP connection failed",-1);
-        return false;
-    }
-
-    if(!@ftp_login($conn, $conf['ftp']['user'], conf_decodeString($conf['ftp']['pass']))){
-        msg("FTP login failed",-1);
-        return false;
-    }
-
-    //create directory
-    $ok = @ftp_mkdir($conn, $dir);
-    //set permissions
-    @ftp_site($conn,sprintf("CHMOD %04o %s",$conf['dmode'],$dir));
-
-    @ftp_close($conn);
-    return $ok;
-}
-
 /**
  * Creates a unique temporary directory and returns
  * its path.
@@ -640,7 +599,8 @@ function io_mktmpdir() {
  *
  * @param string $url           url to download
  * @param string $file          path to file or directory where to save
- * @param bool   $useAttachment if true: try to use name of download, uses otherwise $defaultName, false: uses $file as path to file
+ * @param bool   $useAttachment true: try to use name of download, uses otherwise $defaultName
+ *                              false: uses $file as path to file
  * @param string $defaultName   fallback for if using $useAttachment
  * @param int    $maxSize       maximum file size
  * @return bool|string          if failed false, otherwise true or the name of the file in the given dir
@@ -663,7 +623,7 @@ function io_download($url,$file,$useAttachment=false,$defaultName='',$maxSize=20
             if (is_string($content_disposition) &&
                     preg_match('/attachment;\s*filename\s*=\s*"([^"]*)"/i', $content_disposition, $match)) {
 
-                $name = utf8_basename($match[1]);
+                $name = \dokuwiki\Utf8\PhpString::basename($match[1]);
             }
 
         }
