@@ -2,13 +2,14 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Khalid <khalid.aljahil@gmail.com>
  * @author Mostafa Hussein <mostafa@gmail.com>
  * @author Yaman Hokan <always.smile.yh@hotmail.com>
  * @author Usama Akkad <uahello@gmail.com>
- * @author uahello@gmail.com
  * @author Ahmad Abd-Elghany <tolpa1@gmail.com>
  * @author alhajr <alhajr300@gmail.com>
+ * @author Mohamed Belhsine <b.mohamed897@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'rtl';
@@ -40,7 +41,6 @@ $lang['btn_update']            = 'حدّث';
 $lang['btn_delete']            = 'احذف';
 $lang['btn_back']              = 'ارجع';
 $lang['btn_backlink']          = 'ارتباطات';
-$lang['btn_backtomedia']       = 'ارجع إلى اختيار ملف الوسائط';
 $lang['btn_subscribe']         = 'ادر الاشتراكات';
 $lang['btn_profile']           = 'حدث الملف الشخصي';
 $lang['btn_reset']             = 'صفّر';
@@ -53,7 +53,9 @@ $lang['btn_register']          = 'سجّل';
 $lang['btn_apply']             = 'طبق';
 $lang['btn_media']             = 'مدير الوسائط';
 $lang['btn_deleteuser']        = 'احذف حسابي الخاص';
-$lang['loggedinas']            = 'داخل باسم';
+$lang['btn_img_backto']        = 'عودة إلى %s';
+$lang['btn_mediaManager']      = 'اعرض في مدير الوسائط';
+$lang['loggedinas']            = 'داخل باسم:';
 $lang['user']                  = 'اسم المستخدم';
 $lang['pass']                  = 'كلمة السر';
 $lang['newpass']               = 'كلمة سر جديدة';
@@ -68,42 +70,7 @@ $lang['badpassconfirm']        = 'عذراً,كلمة السر غير صحيحة
 $lang['minoredit']             = 'تعديلات طفيفة';
 $lang['draftdate']             = 'حفظ المسودات آليا مفعّل';
 $lang['nosecedit']             = 'غُيرت الصفحة في هذه الأثناء، معلومات الجزء اصبحت قديمة. حُمُلت كل الصفحة بدلا.';
-$lang['regmissing']            = 'عذرا، عليك ملء جميع الحقول.';
-$lang['reguexists']            = 'عذرا، يوجد مشترك بنفس الاسم.';
-$lang['regsuccess']            = 'أنشئ المستخدم و ارسلت كلمة السر بالبريد.';
-$lang['regsuccess2']           = 'أنشئ المستخدم.';
-$lang['regmailfail']           = 'حدث خطأ فى إرسال رسالة كلمة السر. يرجى مراسلة المدير!';
-$lang['regbadmail']            = 'يبدو البريد الإلكتروني المعطى غيرَ صحيح، إن كنت تظن أن هذا خطأ، راسل المدير';
-$lang['regbadpass']            = 'كلمتا المرور غير متطابقتين، حاول مرة أخرى.';
-$lang['regpwmail']             = 'كلمة مرورك إلى دوكو ويكي';
-$lang['reghere']               = 'ليس لديك حساب بعد؟ احصل على واحد';
-$lang['profna']                = 'هذه الويكي لا تدعم تعديل الملف الشخصي';
-$lang['profnochange']          = 'لا تغييرات، لا شيء ليُعمل.';
-$lang['profnoempty']           = 'غير مسموح باسم مستخدم أو بريد فارغ.';
-$lang['profchanged']           = 'حُدث الملف الشخصي للمستخدم بنجاح.';
-$lang['profnodelete']          = 'هذه الموسوعه لا ندعم حذف الأشخاص';
-$lang['profdeleteuser']        = 'احذف حساب';
-$lang['profdeleted']           = 'حسابك الخاص تم حذفه من هذه الموسوعة';
-$lang['profconfdelete']        = 'أنا أرغب في حذف حسابي من هذه الموسوعة.<br/> 
-هذا الحدث غير ممكن.';
-$lang['pwdforget']             = 'أنسيت كلمة السر؟ احصل على واحدة جديدة';
-$lang['resendna']              = 'هذه الويكي لا تدعم إعادة إرسال كلمة المرور.';
-$lang['resendpwd']             = 'اضبط كلمة سر جديدة لـ';
-$lang['resendpwdmissing']      = 'عذراّ، يجب أن تملأ كل الحقول.';
-$lang['resendpwdnouser']       = 'عذراً، لم نجد المستخدم هذا في قاعدة بياناتنا.';
-$lang['resendpwdbadauth']      = 'عذراً، رمز التفعيل هذا غير صحيح. نأكد من استخدامك كامل وصلة التأكيد.';
-$lang['resendpwdconfirm']      = 'اُرسل رابط التأكيد بواسطة البريد.';
-$lang['resendpwdsuccess']      = 'كلمة السرالجديدة اُرسلت عبر البريد.';
-$lang['license']               = 'مالم يشر لخلاف ذلك، فإن المحتوى في هذه الويكي مرخص وفق الرخصة التالية:';
-$lang['licenseok']             = 'لاحظ: بتحرير هذه الصفحة أنت توافق على ترخيص محتواها تحت الرخصة التالية:';
-$lang['searchmedia']           = 'ابحث في أسماء الملفات:';
-$lang['searchmedia_in']        = 'ابحث في %s';
-$lang['txt_upload']            = 'اختر ملفاً للرفع';
-$lang['txt_filename']          = 'رفع كـ (اختياري)';
-$lang['txt_overwrt']           = 'اكتب على ملف موجود';
-$lang['maxuploadsize']         = 'الحجم الاقصى %s للملف';
-$lang['lockedby']              = 'مقفلة حاليا لـ';
-$lang['lockexpire']            = 'ينتهي القفل في';
+$lang['js']['search_toggle_tools'] = 'إظهار / إخفاء أدوات البحث';
 $lang['js']['willexpire']      = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة.\nلتجنب التعارض استخدم زر المعاينة لتصفير مؤقت القفل.';
 $lang['js']['notsavedyet']     = 'التعديلات غير المحفوظة ستفقد.';
 $lang['js']['searchmedia']     = 'ابحث عن ملفات';
@@ -138,18 +105,66 @@ $lang['js']['del_confirm']     = 'هل حقاً تريد حذف البنود ا
 $lang['js']['restore_confirm'] = 'أمتأكد من استرجاع هذه النسخة؟';
 $lang['js']['media_diff']      = 'عرض الفروق:';
 $lang['js']['media_diff_both'] = 'جنبا إلى جنب';
-$lang['js']['media_diff_opacity'] = 'Shine-through';
-$lang['js']['media_diff_portions'] = 'Swipe';
+$lang['js']['media_diff_portions'] = 'اسحب';
 $lang['js']['media_select']    = 'اختر ملفا...';
 $lang['js']['media_upload_btn'] = 'ارفع';
 $lang['js']['media_done_btn']  = 'تم';
 $lang['js']['media_drop']      = 'اسقط الملف هنا لرفعه';
 $lang['js']['media_cancel']    = 'أزل';
 $lang['js']['media_overwrt']   = 'أكتب فوق الملفات الموجودة';
+$lang['search_exact_match']    = 'تطابق تام';
+$lang['search_starts_with']    = 'يبدأ بالتالي';
+$lang['search_ends_with']      = 'ينتهي بالتالي';
+$lang['search_contains']       = 'يحتوي';
+$lang['search_custom_match']   = 'مخصص';
+$lang['search_any_time']       = 'أي وقت';
+$lang['search_past_7_days']    = 'الأسبوع الماضي';
+$lang['search_past_month']     = 'الشهر الماضي';
+$lang['search_past_year']      = 'السنة الماضية';
+$lang['search_sort_by_hits']   = 'فرز حسب عدد الزيارات';
+$lang['search_sort_by_mtime']  = 'فرز حسب وقت آخر تعديل';
+$lang['regmissing']            = 'عذرا، عليك ملء جميع الحقول.';
+$lang['reguexists']            = 'عذرا، يوجد مشترك بنفس الاسم.';
+$lang['regsuccess']            = 'أنشئ المستخدم و ارسلت كلمة السر بالبريد.';
+$lang['regsuccess2']           = 'أنشئ المستخدم.';
+$lang['regfail']               = 'لا يمكن إنشاء المستخدم.';
+$lang['regmailfail']           = 'حدث خطأ فى إرسال رسالة كلمة السر. يرجى مراسلة المدير!';
+$lang['regbadmail']            = 'يبدو البريد الإلكتروني المعطى غيرَ صحيح، إن كنت تظن أن هذا خطأ، راسل المدير';
+$lang['regbadpass']            = 'كلمتا المرور غير متطابقتين، حاول مرة أخرى.';
+$lang['regpwmail']             = 'كلمة مرورك إلى دوكو ويكي';
+$lang['reghere']               = 'ليس لديك حساب بعد؟ احصل على واحد';
+$lang['profna']                = 'هذه الويكي لا تدعم تعديل الملف الشخصي';
+$lang['profnochange']          = 'لا تغييرات، لا شيء ليُعمل.';
+$lang['profnoempty']           = 'غير مسموح باسم مستخدم أو بريد فارغ.';
+$lang['profchanged']           = 'حُدث الملف الشخصي للمستخدم بنجاح.';
+$lang['profnodelete']          = 'هذه الموسوعه لا ندعم حذف الأشخاص';
+$lang['profdeleteuser']        = 'احذف حساب';
+$lang['profdeleted']           = 'حسابك الخاص تم حذفه من هذه الموسوعة';
+$lang['profconfdelete']        = 'أنا أرغب في حذف حسابي من هذه الموسوعة.<br/>
+هذا الحدث غير ممكن.';
+$lang['profconfdeletemissing'] = 'لم تقم بوضع علامة في مربع التأكيد';
+$lang['proffail']              = 'لم يتم تحديث ملف المستخدم';
+$lang['pwdforget']             = 'أنسيت كلمة السر؟ احصل على واحدة جديدة';
+$lang['resendna']              = 'هذه الويكي لا تدعم إعادة إرسال كلمة المرور.';
+$lang['resendpwd']             = 'اضبط كلمة سر جديدة لـ';
+$lang['resendpwdmissing']      = 'عذراّ، يجب أن تملأ كل الحقول.';
+$lang['resendpwdnouser']       = 'عذراً، لم نجد المستخدم هذا في قاعدة بياناتنا.';
+$lang['resendpwdbadauth']      = 'عذراً، رمز التفعيل هذا غير صحيح. نأكد من استخدامك كامل وصلة التأكيد.';
+$lang['resendpwdconfirm']      = 'اُرسل رابط التأكيد بواسطة البريد.';
+$lang['resendpwdsuccess']      = 'كلمة السرالجديدة اُرسلت عبر البريد.';
+$lang['license']               = 'مالم يشر لخلاف ذلك، فإن المحتوى في هذه الويكي مرخص وفق الرخصة التالية:';
+$lang['licenseok']             = 'لاحظ: بتحرير هذه الصفحة أنت توافق على ترخيص محتواها تحت الرخصة التالية:';
+$lang['searchmedia']           = 'ابحث في أسماء الملفات:';
+$lang['searchmedia_in']        = 'ابحث في %s';
+$lang['txt_upload']            = 'اختر ملفاً للرفع:';
+$lang['txt_filename']          = 'رفع كـ (اختياري):';
+$lang['txt_overwrt']           = 'اكتب على ملف موجود';
+$lang['maxuploadsize']         = 'الحجم الاقصى %s للملف';
+$lang['lockedby']              = 'مقفلة حاليا لـ:';
+$lang['lockexpire']            = 'ينتهي القفل في:';
 $lang['rssfailed']             = 'خطأ ما حدث أثناء جلب ملف التغذية:';
 $lang['nothingfound']          = 'لا يوجد شيء';
 $lang['mediaselect']           = 'ملفات الوسائط';
-$lang['fileupload']            = 'تحميل ملف وسائط';
 $lang['uploadsucc']            = 'تم الرفع بنجاح';
 $lang['uploadfail']            = 'فشل الرفع، ربما خطأ تراخيص؟';
 $lang['uploadwrong']           = 'الرفع ممنوع، نوع الملف مرفوض!';
@@ -183,17 +198,22 @@ $lang['difflink']              = 'رابط إلى هذه المقارنة';
 $lang['diff_type']             = 'أظهر الفروق:';
 $lang['diff_inline']           = 'ضمنا';
 $lang['diff_side']             = 'جنبا إلى جنب';
+$lang['diffprevrev']           = 'المراجعة السابقة';
+$lang['diffnextrev']           = 'المراجعة التالية';
+$lang['difflastrev']           = 'المراجعة الأخيرة';
+$lang['diffbothprevrev']       = 'جانبي المراجعة السابقة';
+$lang['diffbothnextrev']       = 'جانبي المراجعة التالية';
 $lang['line']                  = 'سطر';
-$lang['breadcrumb']            = 'أثر';
-$lang['youarehere']            = 'أنت هنا';
-$lang['lastmod']               = 'آخر تعديل';
+$lang['breadcrumb']            = 'أثر:';
+$lang['youarehere']            = 'أنت هنا:';
+$lang['lastmod']               = 'آخر تعديل:';
 $lang['by']                    = 'بواسطة';
 $lang['deleted']               = 'حذفت';
 $lang['created']               = 'اُنشئت';
 $lang['restored']              = 'استعيدت نسخة قديمة (%s)';
 $lang['external_edit']         = 'تحرير خارجي';
 $lang['summary']               = 'ملخص التحرير';
-$lang['noflash']               = 'تحتاج إلى<a href="http://www.adobe.com/products/flashplayer/">ملحق فلاش أدوبي</a> لعرض هذا المحتوى.';
+$lang['noflash']               = 'تحتاج إلى<a href="http://get.adobe.com/flashplayer">ملحق فلاش أدوبي</a> لعرض هذا المحتوى.';
 $lang['download']              = 'نزل Snippet';
 $lang['tools']                 = 'أدوات';
 $lang['user_tools']            = 'أدوات المستخدم';
@@ -235,24 +255,21 @@ $lang['qb_sig']                = 'أدرج التوقيع';
 $lang['qb_smileys']            = 'الإبتسامات';
 $lang['qb_chars']              = 'محارف خاصة';
 $lang['upperns']               = 'انتقل للنطاق الأب';
-$lang['admin_register']        = 'أضف مستخدما جديدا';
 $lang['metaedit']              = 'تحرير البيانات الشمولية ';
 $lang['metasaveerr']           = 'فشلت كتابة البيانات الشمولية';
 $lang['metasaveok']            = 'حُفظت البيانات الشمولية';
-$lang['btn_img_backto']        = 'عودة إلى %s';
-$lang['img_title']             = 'العنوان';
-$lang['img_caption']           = 'وصف';
-$lang['img_date']              = 'التاريخ';
-$lang['img_fname']             = 'اسم الملف';
-$lang['img_fsize']             = 'الحجم';
-$lang['img_artist']            = 'المصور';
-$lang['img_copyr']             = 'حقوق النسخ';
-$lang['img_format']            = 'الهيئة';
-$lang['img_camera']            = 'الكمرا';
-$lang['img_keywords']          = 'كلمات مفتاحية';
-$lang['img_width']             = 'العرض';
-$lang['img_height']            = 'الإرتفاع';
-$lang['btn_mediaManager']           = 'اعرض في مدير الوسائط';
+$lang['img_title']             = 'العنوان:';
+$lang['img_caption']           = 'وصف:';
+$lang['img_date']              = 'التاريخ:';
+$lang['img_fname']             = 'اسم الملف:';
+$lang['img_fsize']             = 'الحجم:';
+$lang['img_artist']            = 'المصور:';
+$lang['img_copyr']             = 'حقوق النسخ:';
+$lang['img_format']            = 'الهيئة:';
+$lang['img_camera']            = 'الكمرا:';
+$lang['img_keywords']          = 'كلمات مفتاحية:';
+$lang['img_width']             = 'العرض:';
+$lang['img_height']            = 'الإرتفاع:';
 $lang['subscr_subscribe_success'] = 'اضيف %s لقائمة اشتراك %s';
 $lang['subscr_subscribe_error'] = 'خطأ في إضافة %s لقائمة اشتراك %s';
 $lang['subscr_subscribe_noaddress'] = 'ليس هناك عنوان مرتبط بولوجك، لا يمكن اضافتك لقائمة الاشتراك';
@@ -270,7 +287,6 @@ $lang['subscr_style_every']    = 'بريدا على كل تغيير';
 $lang['subscr_style_digest']   = 'البريد الإلكتروني, ملخص للتغييرات لكل صفحة (كل يوم %.2f)';
 $lang['subscr_style_list']     = 'قائمة بالصفحات التي تم تغييرها منذ آخر بريد الإلكتروني (كل يوم %.2f)';
 $lang['authtempfail']          = 'تصريح المشترك غير متوفر مؤقتاً، إن استمرت هذه الحالة يرجى مراسلة المدير';
-$lang['authpwdexpire']         = 'ستنتهي صلاحية كلمة السر في %d . عليك بتغييرها سريعا.';
 $lang['i_chooselang']          = 'اختر لغتك';
 $lang['i_installer']           = 'برنامج تنصيب دوكو ويكي';
 $lang['i_wikiname']            = 'اسم الويكي';
@@ -278,7 +294,7 @@ $lang['i_enableacl']           = 'تفعيل ACL - مفضل';
 $lang['i_superuser']           = 'مشرف';
 $lang['i_problems']            = 'وجد برنامج التنصيب المشاكل التالية، لا يمكنك المتابعة قبل حلها.';
 $lang['i_modified']            = 'لأسباب أمنية هذا البرنامج سيعمل فقط مع تنصيب دوكو ويكي جديد و غير معدّل.
-يجب أن تعيد فك ضغط الملفات مرة أخرى من المكتبة المضغوطة، أو راجع <a href="http://dokuwiki.org/install"> تعليمات تنصيب دوكو ويكي </a> ';
+يجب أن تعيد فك ضغط الملفات مرة أخرى من المكتبة المضغوطة، أو راجع <a href="https://www.dokuwiki.org/install"> تعليمات تنصيب دوكو ويكي </a> ';
 $lang['i_funcna']              = 'دالة PHP التالية غير متوفرة.
 <code>%s</code>
 قد يكون مزود خدمة الاستفادة قد حجبها لسبب ما.';
@@ -287,6 +303,7 @@ $lang['i_phpver']              = 'نسخة PHP التي لديك هي
 وهي أقل من النسخة المطلوبة
 <code>%s</code>
 عليك تحديث نسخة PHP';
+$lang['i_mbfuncoverload']      = 'يجب ايقاف تشغيل mbstring.func_overload في ملف php.ini لتشغيل دوكوويكي.';
 $lang['i_permfail']            = 'إن <code>%s</code> غير قابل للكتابة بواسطة دوكو ويكي، عليك تعديل إعدادات الصلاحيات لهذا المجلد!';
 $lang['i_confexists']          = 'إن <code>%s</code> موجود أصلاً';
 $lang['i_writeerr']            = 'لا يمكن إنشاء <code>%s</code>، عليك التأكد من صلاحيات الملف أو المجلد وإنشاء الملف يدوياً.';
@@ -294,8 +311,8 @@ $lang['i_badhash']             = 'الملف dokuwiki.php غير مصنف أو 
 (hash=<code>%s</code>)';
 $lang['i_badval']              = 'القيمة <code>%s</code> غير شرعية أو فارغة';
 $lang['i_success']             = 'الإعدادات تمت بنجاح، يرجى حذف الملف install.php الآن.
-ثم تابع إلى <a href="doku.php"> دوكو ويكي الجديدة</a>';
-$lang['i_failure']             = 'بعض الأخطاء حدثت أثنا كتابة ملفات الإعدادات، عليك تعديلها يدوياً قبل أن تستطيع استخدام <a href="doku.php"> دوكو ويكي الجديدة</a>';
+ثم تابع إلى <a href="doku.php?id=wiki:welcome"> دوكو ويكي الجديدة</a>';
+$lang['i_failure']             = 'بعض الأخطاء حدثت أثنا كتابة ملفات الإعدادات، عليك تعديلها يدوياً قبل أن تستطيع استخدام <a href="doku.php?id=wiki:welcome"> دوكو ويكي الجديدة</a>';
 $lang['i_policy']              = 'تصريح ACL مبدئي';
 $lang['i_pol0']                = 'ويكي مفتوحة؛ أي القراءة والكتابة والتحميل مسموحة للجميع';
 $lang['i_pol1']                = 'ويكي عامة؛ أي القراءة للجميع ولكن الكتابة والتحميل للمشتركين المسجلين فقط';
@@ -340,4 +357,7 @@ $lang['media_update']          = 'ارفع إصدارا أحدث';
 $lang['media_restore']         = 'استرجع هذه النسخة';
 $lang['currentns']             = 'مساحة الاسم الحالية';
 $lang['searchresult']          = 'نتيجة البحث';
+$lang['plainhtml']             = 'نص HTML غير منسق';
 $lang['wikimarkup']            = 'علامات الوكي';
+$lang['email_signature_text']  = 'أنشئت هذه الرسالة من دوكو ويكي في
+@DOKUWIKIURL@';
