@@ -3,6 +3,9 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Faramarz Karamizadeh <f.karamizadeh@yahoo.com>
+ * @author علیرضا ایوز <info@alirezaivaz.ir>
+ * @author Masoud Sadrnezhaad <masoud@sadrnezhaad.ir>
  * @author behrad eslamifar <behrad_es@yahoo.com)
  * @author Mohsen Firoozmandan <info@mambolearn.com>
  * @author Omid Mottaghi <omidmr@gmail.com>
@@ -16,7 +19,6 @@
  * @author Mohammad Sadegh <msdn2013@gmail.com>
  * @author Omid Hezaveh <hezpublic@gmail.com>
  * @author Mohmmad Razavi <sepent@gmail.com>
- * @author Masoud Sadrnezhaad <masoud@sadrnezhaad.ir>
  * @author sam01 <m.sajad079@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
@@ -38,16 +40,16 @@ $lang['btn_newer']             = 'نتایج بیشتر »';
 $lang['btn_older']             = '« نتایج کمتر';
 $lang['btn_revs']              = 'نگارش‌های پیشین';
 $lang['btn_recent']            = 'تغییرات اخیر';
-$lang['btn_upload']            = 'ارسال';
+$lang['btn_upload']            = 'بارگذاری';
 $lang['btn_cancel']            = 'لغو';
 $lang['btn_index']             = 'فهرست';
 $lang['btn_secedit']           = 'ویرایش';
-$lang['btn_login']             = 'ورود به سیستم';
-$lang['btn_logout']            = 'خروج از سیستم';
+$lang['btn_login']             = 'ورود به سامانه';
+$lang['btn_logout']            = 'خروج از سامانه';
 $lang['btn_admin']             = 'مدیر';
 $lang['btn_update']            = 'به‌روزرسانی';
 $lang['btn_delete']            = 'حذف';
-$lang['btn_back']              = 'عقب';
+$lang['btn_back']              = 'برگشت';
 $lang['btn_backlink']          = 'پیوندهای به این صفحه';
 $lang['btn_subscribe']         = 'عضویت در تغییرات صفحه';
 $lang['btn_profile']           = 'به‌روزرسانی پروفایل';
@@ -57,7 +59,7 @@ $lang['btn_draft']             = 'ویرایش پیش‌نویس';
 $lang['btn_recover']           = 'بازیابی پیش‌نویس';
 $lang['btn_draftdel']          = 'حذف پیش‌نویس';
 $lang['btn_revert']            = 'بازیابی';
-$lang['btn_register']          = 'ثبت نام';
+$lang['btn_register']          = 'نام‌نویسی';
 $lang['btn_apply']             = 'اعمال';
 $lang['btn_media']             = 'مدیریت رسانه‌ها';
 $lang['btn_deleteuser']        = 'حساب کاربری مرا حذف کن';
@@ -71,13 +73,71 @@ $lang['oldpass']               = 'گذرواژه‌ی فعلی را تایید 
 $lang['passchk']               = 'یک بار دیگر';
 $lang['remember']              = 'مرا به خاطر بسپار';
 $lang['fullname']              = 'نام واقعی شما';
-$lang['email']                 = 'ایمیل';
+$lang['email']                 = 'رایانامه';
 $lang['profile']               = 'پروفایل کاربر';
 $lang['badlogin']              = 'متاسفم، نام کاربری یا رمز عبور اشتباه است.';
 $lang['badpassconfirm']        = 'متاسفم، رمز عبور اشتباه است';
 $lang['minoredit']             = 'ویرایش‌های خُرد';
 $lang['draftdate']             = 'ذخیره خودکار پیش‌نویس در';
 $lang['nosecedit']             = 'این صفحه در این میان تغییر کرده است، اطلاعات بخش قدیمی شده است، در عوض محتوای کل نمایش داده می‌شود.';
+$lang['searchcreatepage']      = 'اگر آن چیزی که می‌خواهید را پیدا نکردید، می‌توانید صفحهٔ %s را که هم‌نام درخواست شماست بسازید یا ویرایش کنید.';
+$lang['search_fullresults']    = 'متن کامل نتایج';
+$lang['js']['search_toggle_tools'] = 'فعال یا عدم فعال‌سازی ابزارهای جستجو';
+$lang['js']['willexpire']      = 'حالت قفل شما مدتی است منقضی شده است \n برای جلوگیری از تداخل دکمه‌ی پیش‌نمایش را برای صفر شدن ساعت قفل بزنید.';
+$lang['js']['notsavedyet']     = 'تغییرات ذخیره نشده از بین خواهد رفت.';
+$lang['js']['searchmedia']     = 'جستجو برای فایل‌ها';
+$lang['js']['keepopen']        = 'پنجره را در زمان انتخاب باز نگه‌دار';
+$lang['js']['hidedetails']     = 'پنهان کردن جزئیات';
+$lang['js']['mediatitle']      = 'تنظیمات پیوند';
+$lang['js']['mediadisplay']    = 'نوع پیوند';
+$lang['js']['mediaalign']      = 'هم‌ترازی';
+$lang['js']['mediasize']       = 'اندازه تصویر';
+$lang['js']['mediatarget']     = 'هدف پیوند';
+$lang['js']['mediaclose']      = 'بستن';
+$lang['js']['mediainsert']     = 'درج‌کردن';
+$lang['js']['mediadisplayimg'] = 'نمایش تصویر.';
+$lang['js']['mediadisplaylnk'] = 'فقط پیوند را نمایش بده.';
+$lang['js']['mediasmall']      = 'نگارش کوچک';
+$lang['js']['mediamedium']     = 'نگارش متوسط';
+$lang['js']['medialarge']      = 'نگارش بزرگ';
+$lang['js']['mediaoriginal']   = 'نگارش اصلی';
+$lang['js']['medialnk']        = 'پیوند به صفحه‌ی جزئیات';
+$lang['js']['mediadirect']     = 'پیوند مستقیم به اصلی';
+$lang['js']['medianolnk']      = 'بدون پیوند';
+$lang['js']['medianolink']     = 'تصویر را پیوند نکن';
+$lang['js']['medialeft']       = 'تصویر را با چپ هم‌تراز کن.';
+$lang['js']['mediaright']      = 'تصویر را با راست هم‌تراز کن.';
+$lang['js']['mediacenter']     = 'تصویر را با وسط هم‌تراز کن.';
+$lang['js']['medianoalign']    = 'هم‌تراز نکن.';
+$lang['js']['nosmblinks']      = 'پیوند به Windows share فقط در اینترنت‌اکسپلورر قابل استفاده است.
+شما می‌توانید پیوند‌ها رو کپی کنید.';
+$lang['js']['linkwiz']         = 'ویزارد پیوند';
+$lang['js']['linkto']          = 'پیوند به:';
+$lang['js']['del_confirm']     = 'واقعا تصمیم به حذف این موارد دارید؟';
+$lang['js']['restore_confirm'] = 'آیا مطمئن هستید که می خواهید این نگارش را بازیابی کنید؟';
+$lang['js']['media_diff']      = 'تفاوت ها را ببینید: ';
+$lang['js']['media_diff_both'] = 'پهلو به پهلو';
+$lang['js']['media_diff_opacity'] = 'درخشش از';
+$lang['js']['media_diff_portions'] = 'کش رفتن';
+$lang['js']['media_select']    = 'انتخاب پرونده‌ها...';
+$lang['js']['media_upload_btn'] = 'بارگذاری';
+$lang['js']['media_done_btn']  = 'انجام شد';
+$lang['js']['media_drop']      = 'فایل‌ها را در اینجا قرار دهید تا آپلود شود';
+$lang['js']['media_cancel']    = 'حذف';
+$lang['js']['media_overwrt']   = 'جاینوشت فایل‌های موجود';
+$lang['js']['data_insecure']   = 'هشدار: به نظر می رسد فهرست اطلاعات شما به درستی ایمن نشده است. لطفاً درباره <a href="https://www.dokuwiki.org/security#web_access_security">Web Access Security in DokuWiki</a> بخوانید.';
+$lang['search_exact_match']    = 'دقیقا برابر';
+$lang['search_starts_with']    = 'شروع بشود با';
+$lang['search_ends_with']      = 'پایان یابد با';
+$lang['search_contains']       = 'شامل';
+$lang['search_custom_match']   = 'دلخواه';
+$lang['search_any_ns']         = 'هر فضای نام';
+$lang['search_any_time']       = 'هر زمان';
+$lang['search_past_7_days']    = 'هفتهٔ قبل';
+$lang['search_past_month']     = 'ماه قبل';
+$lang['search_past_year']      = 'سال قبل';
+$lang['search_sort_by_hits']   = 'مرتب کردن برحسب تعداد بازدید';
+$lang['search_sort_by_mtime']  = 'مرتب کردن برحسب آخرین ویرایش';
 $lang['regmissing']            = 'متاسفم، شما باید همه قسمت‌ها را پر کنید.';
 $lang['reguexists']            = 'نام کاربری‌ای که وارد کردید قبلن استفاده شده است.';
 $lang['regsuccess']            = 'کاربر ساخته شد و گذرواژه به صورت ایمیل ارسال گردید.';
@@ -114,50 +174,9 @@ $lang['txt_upload']            = 'فایل را برای آپلود انتخاب
 $lang['txt_filename']          = 'ارسال به صورت (اختیاری):';
 $lang['txt_overwrt']           = 'بر روی فایل موجود بنویس';
 $lang['maxuploadsize']         = 'حداکثر %s برای هر فایل مجاز است.';
+$lang['allowedmime']           = 'لیست پسوندهای مجاز فایل';
 $lang['lockedby']              = 'در حال حاضر قفل شده است:';
 $lang['lockexpire']            = 'قفل منقضی می‌شود در:';
-$lang['js']['willexpire']      = 'حالت قفل شما مدتی است منقضی شده است \n برای جلوگیری از تداخل دکمه‌ی پیش‌نمایش را برای صفر شدن ساعت قفل بزنید.';
-$lang['js']['notsavedyet']     = 'تغییرات ذخیره نشده از بین خواهد رفت.';
-$lang['js']['searchmedia']     = 'جستجو برای فایل‌ها';
-$lang['js']['keepopen']        = 'پنجره را در زمان انتخاب باز نگه‌دار';
-$lang['js']['hidedetails']     = 'پنهان کردن جزئیات';
-$lang['js']['mediatitle']      = 'تنظیمات پیوند';
-$lang['js']['mediadisplay']    = 'نوع پیوند';
-$lang['js']['mediaalign']      = 'هم‌ترازی';
-$lang['js']['mediasize']       = 'اندازه تصویر';
-$lang['js']['mediatarget']     = 'هدف پیوند';
-$lang['js']['mediaclose']      = 'بستن';
-$lang['js']['mediainsert']     = 'درج کردن';
-$lang['js']['mediadisplayimg'] = 'نمایش تصویر.';
-$lang['js']['mediadisplaylnk'] = 'فقط پیوند را نمایش بده.';
-$lang['js']['mediasmall']      = 'نگارش کوچک';
-$lang['js']['mediamedium']     = 'نگارش متوسط';
-$lang['js']['medialarge']      = 'نگارش بزرگ';
-$lang['js']['mediaoriginal']   = 'نگارش اصلی';
-$lang['js']['medialnk']        = 'پیوند به صفحه‌ی جزئیات';
-$lang['js']['mediadirect']     = 'پیوند مستقیم به اصلی';
-$lang['js']['medianolnk']      = 'بدون پیوند';
-$lang['js']['medianolink']     = 'تصویر را پیوند نکن';
-$lang['js']['medialeft']       = 'تصویر را با چپ هم‌تراز کن.';
-$lang['js']['mediaright']      = 'تصویر را با راست هم‌تراز کن.';
-$lang['js']['mediacenter']     = 'تصویر را با وسط هم‌تراز کن.';
-$lang['js']['medianoalign']    = 'هم‌تراز نکن.';
-$lang['js']['nosmblinks']      = 'پیوند به Windows share فقط در اینترنت‌اکسپلورر قابل استفاده است.
-شما می‌توانید پیوند‌ها رو کپی کنید.';
-$lang['js']['linkwiz']         = 'ویزارد پیوند';
-$lang['js']['linkto']          = 'پیوند به:';
-$lang['js']['del_confirm']     = 'واقعا تصمیم به حذف این موارد دارید؟';
-$lang['js']['restore_confirm'] = 'آیا مطمئن هستید که می خواهید این نگارش را بازیابی کنید؟';
-$lang['js']['media_diff']      = 'تفاوت ها را ببینید: ';
-$lang['js']['media_diff_both'] = 'پهلو به پهلو';
-$lang['js']['media_diff_opacity'] = 'درخشش از';
-$lang['js']['media_diff_portions'] = 'کش رفتن';
-$lang['js']['media_select']    = 'انتخاب فایل‌ها...';
-$lang['js']['media_upload_btn'] = 'آپلود';
-$lang['js']['media_done_btn']  = 'انجام شد';
-$lang['js']['media_drop']      = 'فایل‌ها را در اینجا قرار دهید تا آپلود شود';
-$lang['js']['media_cancel']    = 'حذف';
-$lang['js']['media_overwrt']   = 'جاینوشت فایل‌های موجود';
 $lang['rssfailed']             = 'بروز خطا در هنگام واکشی این فید:';
 $lang['nothingfound']          = 'چیزی پیدا نشد.';
 $lang['mediaselect']           = 'فایل‌ها';
@@ -209,7 +228,7 @@ $lang['created']               = 'ایجاد شد';
 $lang['restored']              = 'یک نگارش پیشین واگردانی شد. (%s)';
 $lang['external_edit']         = 'ویرایش خارجی';
 $lang['summary']               = 'پیش‌نمایش';
-$lang['noflash']               = 'برای نمایش محتویات <a href="http://www.adobe.com/products/flashplayer/">افزونه‌ی فلش</a> مورد نیاز است.';
+$lang['noflash']               = 'برای نمایش محتویات <a href="http://get.adobe.com/flashplayer">افزونه‌ی فلش</a> مورد نیاز است.';
 $lang['download']              = 'دیافت فایل منقطع گردید';
 $lang['tools']                 = 'ابزار';
 $lang['user_tools']            = 'ابزار کاربر';
@@ -289,8 +308,10 @@ $lang['i_wikiname']            = 'نام ویکی';
 $lang['i_enableacl']           = 'فعال بودن کنترل دسترسی‌ها (توصیه شده)';
 $lang['i_superuser']           = 'کاربر اصلی';
 $lang['i_problems']            = 'نصب کننده با مشکلات زیر مواجه شد. در صورت رفع این مشکلات، امکان ادامه نصب خواهد بود.';
-$lang['i_modified']            = 'به دلایل امنیتی، این اسکریپت فقط با نصب تازه و بدون تغییر دوکوویکی کار خواهد کرد. شما باید دوباره فایل فشرده را باز کنید <a href="http://dokuwiki.org/install">راهنمای نصب DokuWiki</a> را بررسی کنید.';
+$lang['i_modified']            = 'به دلایل امنیتی، این اسکریپت فقط با نصب تازه و بدون تغییر دوکوویکی کار خواهد کرد. شما باید دوباره فایل فشرده را باز کنید <a href="https://www.dokuwiki.org/install">راهنمای نصب DokuWiki</a> را بررسی کنید.';
 $lang['i_funcna']              = 'تابع <code>%s</code> در پی‌اچ‌پی موجود نیست. ممکن است شرکت خدمات وب شما آن را مسدود کرده باشد.';
+$lang['i_disabled']            = 'توسط ارائه دهنده شما غیرفعال شده است.';
+$lang['i_funcnmail']           = '<b>توجه:</b> PHP mail function در دسترس نیست. %s اگر در دسترس نیست، می‌توانید افزونه <a href="https://www.dokuwiki.org/plugin:smtp">smtp</a> را نصب کنید.';
 $lang['i_phpver']              = 'نگارش پی‌اچ‌پی <code>%s</code> پایین‌تر از نگارش مورد نیاز، یعنی <code>%s</code> است. خواهشمندیم به روز رسانی کنید.';
 $lang['i_mbfuncoverload']      = 'برای اجرای دوکوویکی باید mbstring.func_overload را در php.ini غیرفعال کنید.';
 $lang['i_permfail']            = 'شاخه‌ی <code>%s</code> قابلیت نوشتن ندارد. شما باید دسترسی‌های این شاخه را تنظیم کنید!';
@@ -343,6 +364,7 @@ $lang['media_perm_upload']     = 'متاسفانه شما دسترسی‌های
 $lang['media_update']          = 'آپلود نسخه‌ی جدید';
 $lang['media_restore']         = 'بازیابی این نسخه';
 $lang['media_acl_warning']     = 'این لیست ممکن است به خاطر محدودیتهای دسترسیهای ACL و صفحات پنهان کامل نباشد.';
+$lang['email_fail']            = 'PHP Mail() یافت نشد یا غیرفعال است. ایمیل زیر ارسال نشد:';
 $lang['currentns']             = 'فضای نام جاری';
 $lang['searchresult']          = 'نتیجه‌ی جستجو';
 $lang['plainhtml']             = 'HTML ساده';
