@@ -2,7 +2,9 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author HokkaidoPerson <dosankomali@yahoo.co.jp>
+ * @author lempel <riverlempel@hotmail.com>
  * @author Yuji Takenaka <webmaster@davilin.com>
  * @author Ikuo Obataya <i.obataya@gmail.com>
  * @author Daniel Dupriest <kououken@gmail.com>
@@ -10,7 +12,7 @@
  * @author Taisuke Shimamoto <dentostar@gmail.com>
  * @author Satoshi Sahara <sahara.satoshi@gmail.com>
  * @author Hideaki SAWADA <chuno@live.jp>
- * @author Hideaki SAWADA <sawadakun@live.jp>
+ * @author PzF_X <jp_minecraft@yahoo.co.jp>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -42,11 +44,10 @@ $lang['btn_update']            = '更新';
 $lang['btn_delete']            = '削除';
 $lang['btn_back']              = '戻る';
 $lang['btn_backlink']          = 'バックリンク';
-$lang['btn_backtomedia']       = 'メディアファイル選択に戻る';
 $lang['btn_subscribe']         = '変更履歴配信の登録';
 $lang['btn_profile']           = 'ユーザー情報の更新';
 $lang['btn_reset']             = 'リセット';
-$lang['btn_resendpwd']         = '新しいパスワードをセット';
+$lang['btn_resendpwd']         = '新しいパスワードを設定';
 $lang['btn_draft']             = 'ドラフトを編集';
 $lang['btn_recover']           = 'ドラフトを復元';
 $lang['btn_draftdel']          = 'ドラフトを削除';
@@ -54,65 +55,34 @@ $lang['btn_revert']            = '元に戻す';
 $lang['btn_register']          = 'ユーザー登録';
 $lang['btn_apply']             = '適用';
 $lang['btn_media']             = 'メディアマネージャー';
-$lang['btn_deleteuser']        = '自分のアカウントの抹消';
-$lang['loggedinas']            = 'ようこそ';
+$lang['btn_deleteuser']        = '自分のアカウントを抹消する';
+$lang['btn_img_backto']        = '%sへ戻る';
+$lang['btn_mediaManager']      = 'メディアマネージャーで閲覧';
+$lang['loggedinas']            = 'ようこそ:';
 $lang['user']                  = 'ユーザー名';
 $lang['pass']                  = 'パスワード';
 $lang['newpass']               = '新しいパスワード';
-$lang['oldpass']               = '現在のパスワード';
-$lang['passchk']               = '確認';
-$lang['remember']              = 'ユーザー名とパスワードを記憶する';
+$lang['oldpass']               = '現在のパスワードを確認';
+$lang['passchk']               = '確認のため再入力';
+$lang['remember']              = 'ログインを保持する';
 $lang['fullname']              = 'フルネーム';
 $lang['email']                 = 'メールアドレス';
 $lang['profile']               = 'ユーザー情報';
-$lang['badlogin']              = 'ユーザー名かパスワードが違います。';
-$lang['badpassconfirm']        = 'パスワードが間違っています。';
+$lang['badlogin']              = 'ユーザー名もしくはパスワードに誤りがあります。';
+$lang['badpassconfirm']        = 'パスワードに誤りがあります。';
 $lang['minoredit']             = '小変更';
 $lang['draftdate']             = 'ドラフト保存日時：';
-$lang['nosecedit']             = 'ページ内容が変更されていますがセクション情報が古いため、代わりにページ全体をロードしました。';
-$lang['regmissing']            = '全ての項目を入力してください。';
-$lang['reguexists']            = 'このユーザー名は既に存在しています。';
-$lang['regsuccess']            = '新しいユーザーが作成されました。パスワードは登録したメールアドレス宛てに送付されます。';
-$lang['regsuccess2']           = '新しいユーザーが作成されました。';
-$lang['regmailfail']           = 'パスワードのメール送信に失敗しました。お手数ですが管理者まで連絡をお願いします。';
-$lang['regbadmail']            = 'メールアドレスが有効ではありません。';
-$lang['regbadpass']            = '確認用のパスワードが正しくありません。';
-$lang['regpwmail']             = 'あなたの DokuWiki パスワード';
-$lang['reghere']               = 'ご自分用のアカウントを取ってみては如何ですか？';
-$lang['profna']                = 'ユーザー情報の変更は出来ません';
-$lang['profnochange']          = '変更点はありませんでした。';
-$lang['profnoempty']           = 'ユーザー名とメールアドレスを入力して下さい。';
-$lang['profchanged']           = 'ユーザー情報は更新されました。';
-$lang['profnodelete']          = 'この wiki はユーザーを削除できない。';
-$lang['profdeleteuser']        = 'アカウントの削除';
-$lang['profdeleted']           = 'このwikiからあなたのユーザーアカウントは削除済です。';
-$lang['profconfdelete']        = 'このwikiから自分のアカウント抹消を希望します。<br/> この操作は取消すことができません。';
-$lang['profconfdeletemissing'] = '確認のチェックボックスがチェックされていません。';
-$lang['pwdforget']             = 'パスワードをお忘れですか？パスワード再発行';
-$lang['resendna']              = 'パスワードの再発行は出来ません。';
-$lang['resendpwd']             = '新しいパスワードをセット';
-$lang['resendpwdmissing']      = '全ての項目を入力して下さい。';
-$lang['resendpwdnouser']       = '入力されたユーザーが見つかりませんでした。';
-$lang['resendpwdbadauth']      = '申し訳ありません。この確認コードは有効ではありません。メール内に記載されたリンクを確認してください。';
-$lang['resendpwdconfirm']      = '確認用のリンクを含んだメールを送信しました。';
-$lang['resendpwdsuccess']      = '新しいパスワードがメールで送信されました。';
-$lang['license']               = '特に明示されていない限り、本Wikiの内容は次のライセンスに従います：';
-$lang['licenseok']             = '注意： 本ページを編集することは、あなたの編集した内容が次のライセンスに従うことに同意したものとみなします：';
-$lang['searchmedia']           = '検索ファイル名：';
-$lang['searchmedia_in']        = '%s 内を検索';
-$lang['txt_upload']            = 'アップロードするファイルを選んでください。';
-$lang['txt_filename']          = '名前を変更してアップロード（オプション）';
-$lang['txt_overwrt']           = '既存のファイルを上書き';
-$lang['maxuploadsize']         = 'アップロード上限サイズ %s /ファイル';
-$lang['lockedby']              = 'この文書は次のユーザーによってロックされています';
-$lang['lockexpire']            = 'ロック期限：';
-$lang['js']['willexpire']      = '編集中の文書はロック期限を過ぎようとしています。このままロックする場合は、一度文書の確認を行って期限をリセットしてください。';
-$lang['js']['notsavedyet']     = '変更は保存されません。このまま処理を続けてよろしいですか？';
+$lang['nosecedit']             = '読み込みまでの間にページ内容が変更され、セクション情報が古くなったため、代わりにページ全体をロードしました。';
+$lang['searchcreatepage']      = 'もしお探しの内容が見つからなければ、検索キーワードに因んだ「%s」という名前のページを作成・編集出来ます。';
+$lang['search_fullresults']    = '全文検索';
+$lang['js']['search_toggle_tools'] = '検索ツールを表示／非表示';
+$lang['js']['willexpire']      = '編集中の文書のロックが、間もなく期限切れとなります。\n編集の競合を防ぐには、一度「プレビュー」ボタンを押してロック期限をリセットしてください。';
+$lang['js']['notsavedyet']     = '保存していない変更は失われます。';
 $lang['js']['searchmedia']     = 'ファイル検索';
 $lang['js']['keepopen']        = '選択中はウィンドウを閉じない';
 $lang['js']['hidedetails']     = '詳細を非表示';
 $lang['js']['mediatitle']      = 'リンク設定';
-$lang['js']['mediadisplay']    = 'リンクタイプ';
+$lang['js']['mediadisplay']    = 'リンクのタイプ';
 $lang['js']['mediaalign']      = '位置';
 $lang['js']['mediasize']       = 'イメージサイズ';
 $lang['js']['mediatarget']     = 'リンク先';
@@ -127,12 +97,12 @@ $lang['js']['mediaoriginal']   = 'オリジナルのサイズ';
 $lang['js']['medialnk']        = '詳細ページへのリンク';
 $lang['js']['mediadirect']     = 'オリジナルへの直リンク';
 $lang['js']['medianolnk']      = 'リンク無し';
-$lang['js']['medianolink']     = 'イメージをリンクしない';
-$lang['js']['medialeft']       = 'イメージを左に寄せる';
-$lang['js']['mediaright']      = 'イメージを右に寄せる';
-$lang['js']['mediacenter']     = 'イメージを中央に寄せる';
+$lang['js']['medianolink']     = '画像へリンクしない';
+$lang['js']['medialeft']       = '画像を左に寄せる';
+$lang['js']['mediaright']      = '画像を右に寄せる';
+$lang['js']['mediacenter']     = '画像を中央に寄せる';
 $lang['js']['medianoalign']    = '位置を設定しない';
-$lang['js']['nosmblinks']      = 'ウィンドウズの共有フォルダへリンクは Microsoft Internet Explorer でしか機能しませんが、リンクをコピーして貼り付けることは可能です。';
+$lang['js']['nosmblinks']      = 'Windows の共有フォルダへリンクは Microsoft Internet Explorer でしか機能しませんが、リンクをコピーして貼り付けることは可能です。';
 $lang['js']['linkwiz']         = 'リンクウィザード';
 $lang['js']['linkto']          = 'リンク先：';
 $lang['js']['del_confirm']     = '選択した項目を本当に削除しますか？';
@@ -147,32 +117,81 @@ $lang['js']['media_done_btn']  = '完了';
 $lang['js']['media_drop']      = 'ここにファイルをドロップするとアップロードします';
 $lang['js']['media_cancel']    = '削除';
 $lang['js']['media_overwrt']   = '既存のファイルを上書きする';
-$lang['rssfailed']             = 'RSSの取得に失敗しました：';
+$lang['search_exact_match']    = '完全一致';
+$lang['search_starts_with']    = '前方一致';
+$lang['search_ends_with']      = '後方一致';
+$lang['search_contains']       = '部分一致';
+$lang['search_custom_match']   = 'カスタム';
+$lang['search_any_ns']         = '全ての名前空間';
+$lang['search_any_time']       = '全期間';
+$lang['search_past_7_days']    = '1週間以内';
+$lang['search_past_month']     = '1カ月以内';
+$lang['search_past_year']      = '1年以内';
+$lang['search_sort_by_hits']   = 'ヒット数順に並べる';
+$lang['search_sort_by_mtime']  = '最終更新順に並べる';
+$lang['regmissing']            = 'お手数ですが、全ての項目を入力してください。';
+$lang['reguexists']            = '恐れ入りますが、このユーザー名は既に存在しています。';
+$lang['regsuccess']            = '新しいユーザーが作成されました。パスワードは登録したメールアドレス宛てに送付されます。';
+$lang['regsuccess2']           = '新しいユーザーが作成されました。';
+$lang['regfail']               = 'ユーザーを作成できませんでした。';
+$lang['regmailfail']           = 'パスワードのメールを送信する際にエラーが生じた模様です。お手数ですが管理者まで連絡をお願いします。';
+$lang['regbadmail']            = 'メールアドレスが有効でないと判断されました。不具合だと思われる場合は、管理者にご連絡下さい。';
+$lang['regbadpass']            = '確認用のパスワードが正しくありません。もう一度お試し下さい。';
+$lang['regpwmail']             = 'あなたの DokuWiki パスワード';
+$lang['reghere']               = 'ご自分用のアカウントを取ってみてはいかがですか？';
+$lang['profna']                = 'このWikiではユーザー情報の変更は出来ません';
+$lang['profnochange']          = '変更点が無かったため、システム側では何も操作を行いませんでした。';
+$lang['profnoempty']           = 'ユーザー名とメールアドレスを入力して下さい。';
+$lang['profchanged']           = 'ユーザー情報は更新されました。';
+$lang['profnodelete']          = 'このWikiではユーザーを削除出来ません';
+$lang['profdeleteuser']        = 'アカウントの削除';
+$lang['profdeleted']           = 'あなたのユーザーアカウントはこのWikiから削除されました。';
+$lang['profconfdelete']        = 'このWikiから自分のアカウントを消去する場合はチェックボックスにチェックを入れて下さい。<br/> この操作は取消すことができません。';
+$lang['profconfdeletemissing'] = '確認のチェックボックスがチェックされていません。';
+$lang['proffail']              = 'ユーザー情報は更新されませんでした。';
+$lang['pwdforget']             = 'パスワードをお忘れですか？';
+$lang['resendna']              = 'このWikiではパスワードの再発行は出来ません。';
+$lang['resendpwd']             = '新しいパスワードを設定';
+$lang['resendpwdmissing']      = 'お手数ですが、全ての項目を入力して下さい。';
+$lang['resendpwdnouser']       = '恐れ入りますが、入力されたユーザーがデータベース上にありませんでした。';
+$lang['resendpwdbadauth']      = '申し訳ありませんが、この確認コードは有効ではありません。URLが一部のみ切り取られていないかどうか、メール内に記載されたリンクをご確認下さい。';
+$lang['resendpwdconfirm']      = '確認用のリンクを含んだメールを送信しました。';
+$lang['resendpwdsuccess']      = '新しいパスワードがメールで送信されました。';
+$lang['license']               = '特に明示されていない限り、本Wikiの内容は次のライセンスに従います：';
+$lang['licenseok']             = '注意： 本ページを編集した場合、あなたの編集した内容が次のライセンスに従うことに同意したものとみなします：';
+$lang['searchmedia']           = 'ファイル名を検索：';
+$lang['searchmedia_in']        = '%s 内を検索';
+$lang['txt_upload']            = 'アップロードするファイルを選んでください:';
+$lang['txt_filename']          = '名前を変更してアップロード（任意）:';
+$lang['txt_overwrt']           = '既存のファイルを上書き';
+$lang['maxuploadsize']         = 'アップロード上限サイズ：1ファイルにつき%s';
+$lang['lockedby']              = '文書をロックしているユーザー：';
+$lang['lockexpire']            = 'ロック期限：';
+$lang['rssfailed']             = 'フィードの取得中にエラーが発生しました：';
 $lang['nothingfound']          = '該当文書はありませんでした。';
 $lang['mediaselect']           = 'メディアファイル';
-$lang['fileupload']            = 'メディアファイルをアップロード';
 $lang['uploadsucc']            = 'アップロード完了';
 $lang['uploadfail']            = 'アップロードに失敗しました。権限がありません。';
 $lang['uploadwrong']           = 'アップロードは拒否されました。この拡張子は許可されていません。';
 $lang['uploadexist']           = '同名のファイルが存在するため、アップロードできません。';
 $lang['uploadbadcontent']      = 'アップロードされたファイルの内容は、拡張子 %s と一致しません。';
-$lang['uploadspam']            = 'スパムブラックリストによりアップロードが遮断されました。';
-$lang['uploadxss']             = '悪意のある内容である可能性により、アップロードが遮断されました。';
-$lang['uploadsize']            = 'アップロードしようとしたファイルは大きすぎます（最大 %s）。';
+$lang['uploadspam']            = 'スパム ブラックリストによりアップロードが遮断されました。';
+$lang['uploadxss']             = '悪意のある内容を含んでいる可能性がある為、アップロードが遮断されました。';
+$lang['uploadsize']            = 'ファイルのサイズが大きすぎます（最大 %s）。';
 $lang['deletesucc']            = 'ファイル "%s" は削除されました。';
 $lang['deletefail']            = 'ファイル "%s" が削除できません。権限を確認して下さい。';
 $lang['mediainuse']            = 'ファイル "%s" は使用中のため、削除されませんでした。';
 $lang['namespaces']            = '名前空間';
-$lang['mediafiles']            = '有効なファイル：';
+$lang['mediafiles']            = '利用可能なファイル：';
 $lang['accessdenied']          = 'このページを閲覧する権限がありません。';
-$lang['mediausage']            = 'このファイルを使用するためには次の文法を使用する：';
+$lang['mediausage']            = 'このファイルを使用するには次のWiki文法を使用して下さい。';
 $lang['mediaview']             = 'オリジナルファイルを閲覧';
 $lang['mediaroot']             = 'ルート';
-$lang['mediaupload']           = 'ファイルを現在の名前空間にアップロードします。副名前空間を使用する場合には、ファイル名の前にコロンで区切って追加してください。';
+$lang['mediaupload']           = 'ファイルを現在の名前空間にアップロードします。副名前空間を使用する場合には、ファイルを選択後、ファイル名の前にコロンで区切って追加してください。ドラッグ&ドロップでファイルを選択する事も出来ます。';
 $lang['mediaextchange']        = '拡張子が .%s から .%s へ変更されました。';
 $lang['reference']             = '参照先';
 $lang['ref_inuse']             = 'このファイルは、次のページで使用中のため削除できません。';
-$lang['ref_hidden']            = 'このページに存在するいくつかの参照先は、権限が無いため読むことができません。';
+$lang['ref_hidden']            = 'このページに存在するいくつかの参照先は、権限が無いため読み込むことができません。';
 $lang['hits']                  = 'ヒット';
 $lang['quickhits']             = 'マッチした文書名';
 $lang['toc']                   = '目次';
@@ -180,21 +199,26 @@ $lang['current']               = '現在';
 $lang['yours']                 = 'あなたのバージョン';
 $lang['diff']                  = '現在のリビジョンとの差分を表示';
 $lang['diff2']                 = '選択したリビジョン間の差分を表示';
-$lang['difflink']              = 'この比較画面にリンクする';
+$lang['difflink']              = 'この比較画面へのリンク';
 $lang['diff_type']             = '差分の表示方法：';
 $lang['diff_inline']           = 'インライン';
 $lang['diff_side']             = '横に並べる';
-$lang['line']                  = 'ライン';
-$lang['breadcrumb']            = 'トレース';
-$lang['youarehere']            = '現在位置';
-$lang['lastmod']               = '最終更新';
+$lang['diffprevrev']           = '前のリビジョン';
+$lang['diffnextrev']           = '次のリビジョン';
+$lang['difflastrev']           = '最新のリビジョン';
+$lang['diffbothprevrev']       = '両方とも前のリビジョン';
+$lang['diffbothnextrev']       = '両方とも次のリビジョン';
+$lang['line']                  = '行';
+$lang['breadcrumb']            = 'トレース:';
+$lang['youarehere']            = '現在位置:';
+$lang['lastmod']               = '最終更新:';
 $lang['by']                    = 'by';
 $lang['deleted']               = '削除';
 $lang['created']               = '作成';
 $lang['restored']              = '以前のリビジョンを復元 (%s)';
 $lang['external_edit']         = '外部編集';
 $lang['summary']               = '編集の概要';
-$lang['noflash']               = 'この内容を表示するためには <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> が必要です。';
+$lang['noflash']               = 'この内容を表示するには <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> が必要です。';
 $lang['download']              = 'この部分をダウンロード';
 $lang['tools']                 = 'ツール';
 $lang['user_tools']            = 'ユーザ用ツール';
@@ -214,7 +238,7 @@ $lang['both_changes']          = 'ページとメディアファイルの変更'
 $lang['qb_bold']               = '太字';
 $lang['qb_italic']             = '斜体';
 $lang['qb_underl']             = '下線';
-$lang['qb_code']               = 'コード';
+$lang['qb_code']               = '等幅';
 $lang['qb_strike']             = '打消線';
 $lang['qb_h1']                 = '第一見出し';
 $lang['qb_h2']                 = '第二見出し';
@@ -222,7 +246,7 @@ $lang['qb_h3']                 = '第三見出し';
 $lang['qb_h4']                 = '第四見出し';
 $lang['qb_h5']                 = '第五見出し';
 $lang['qb_h']                  = '見出し';
-$lang['qb_hs']                 = '見出し選択';
+$lang['qb_hs']                 = '見出し（階層を選択）';
 $lang['qb_hplus']              = '上の階層の見出し';
 $lang['qb_hminus']             = '下の階層の見出し';
 $lang['qb_hequal']             = '同じ階層の見出し';
@@ -231,34 +255,31 @@ $lang['qb_extlink']            = '外部リンク';
 $lang['qb_hr']                 = '横罫線';
 $lang['qb_ol']                 = '記号付きリスト';
 $lang['qb_ul']                 = '記号なしリスト';
-$lang['qb_media']              = 'イメージやファイルの追加';
+$lang['qb_media']              = 'イメージやファイルの追加（新しいウィンドウで開きます）';
 $lang['qb_sig']                = '署名の挿入';
 $lang['qb_smileys']            = 'スマイリー';
 $lang['qb_chars']              = '特殊文字';
 $lang['upperns']               = '上の階層の名前空間へ';
-$lang['admin_register']        = '新規ユーザー作成';
 $lang['metaedit']              = 'メタデータ編集';
 $lang['metasaveerr']           = 'メタデータの書き込みに失敗しました';
 $lang['metasaveok']            = 'メタデータは保存されました';
-$lang['btn_img_backto']            = '戻る %s';
-$lang['img_title']             = 'タイトル';
-$lang['img_caption']           = '見出し';
-$lang['img_date']              = '日付';
-$lang['img_fname']             = 'ファイル名';
-$lang['img_fsize']             = 'サイズ';
-$lang['img_artist']            = '作成者';
-$lang['img_copyr']             = '著作権';
-$lang['img_format']            = 'フォーマット';
-$lang['img_camera']            = '使用カメラ';
-$lang['img_keywords']          = 'キーワード';
-$lang['img_width']             = '幅';
-$lang['img_height']            = '高さ';
-$lang['btn_mediaManager']           = 'メディアマネージャーで閲覧';
+$lang['img_title']             = 'タイトル:';
+$lang['img_caption']           = '見出し:';
+$lang['img_date']              = '日付:';
+$lang['img_fname']             = 'ファイル名:';
+$lang['img_fsize']             = 'サイズ:';
+$lang['img_artist']            = '作成者:';
+$lang['img_copyr']             = '著作権:';
+$lang['img_format']            = 'フォーマット:';
+$lang['img_camera']            = '使用カメラ:';
+$lang['img_keywords']          = 'キーワード:';
+$lang['img_width']             = '幅:';
+$lang['img_height']            = '高さ:';
 $lang['subscr_subscribe_success'] = '%sが%sの購読リストに登録されました。';
-$lang['subscr_subscribe_error'] = '%sを%sの購読リストへの追加に失敗しました。';
+$lang['subscr_subscribe_error'] = '%sを%sの購読リストへ追加するのに失敗しました。';
 $lang['subscr_subscribe_noaddress'] = 'あなたのログインに対応するアドレスがないため、購読リストへ追加することができません。';
 $lang['subscr_unsubscribe_success'] = '%sを%sの購読リストから削除しました。';
-$lang['subscr_unsubscribe_error'] = '%sを%sの購読リストからの削除に失敗しました。';
+$lang['subscr_unsubscribe_error'] = '%sを%sの購読リストから削除するのに失敗しました。';
 $lang['subscr_already_subscribed'] = '%sは既に%sに登録されています。';
 $lang['subscr_not_subscribed'] = '%sは%sに登録されていません。';
 $lang['subscr_m_not_subscribed'] = '現在のページ、もしくは名前空間にあなたは登録されていません。';
@@ -270,9 +291,8 @@ $lang['subscr_m_receive']      = '受信';
 $lang['subscr_style_every']    = '全ての変更にメールを送信';
 $lang['subscr_style_digest']   = 'それぞれのページへの変更の要約をメールする（%.2f 日毎）';
 $lang['subscr_style_list']     = '前回のメールから変更されたページをリスト（%.2f 日毎）';
-$lang['authtempfail']          = 'ユーザー認証が一時的に使用できなくなっています。この状態が続いているようであれば、Wikiの管理者に連絡して下さい。';
-$lang['authpwdexpire']         = 'あなたのパスワードは、あと%d日で有効期限が切れます。パスワードを変更してください。';
-$lang['i_chooselang']          = '使用言語を選択してください';
+$lang['authtempfail']          = 'ユーザー認証が一時的に使用できなくなっています。問題が解決しない場合は、Wikiの管理者に連絡して下さい。';
+$lang['i_chooselang']          = '使用言語を選択';
 $lang['i_installer']           = 'DokuWiki インストーラー';
 $lang['i_wikiname']            = 'Wiki名';
 $lang['i_enableacl']           = 'ACL（アクセス管理）を使用する（推奨）';
@@ -280,27 +300,31 @@ $lang['i_superuser']           = 'スーパーユーザー';
 $lang['i_problems']            = '問題が発見されました。以下に示す問題を解決するまで、インストールを続行できません。';
 $lang['i_modified']            = 'セキュリティの理由から、新規もしくはカスタマイズしていない DokuWiki に対してのみ、このスクリプトは有効です。
                          ダウンロードしたパッケージを再解凍して使用するか、
-                         <a href="http://dokuwiki.org/install">Dokuwiki インストールガイド</a>を参考にしてインストールしてください。';
+                         <a href="https://www.dokuwiki.org/install">Dokuwiki インストールガイド</a>を参考にしてインストールしてください。';
 $lang['i_funcna']              = 'PHPの関数 <code>%s</code> が使用できません。ホスティング会社が何らかの理由で無効にしている可能性があります。';
+$lang['i_disabled']            = 'ご利用のプロバイダにより制限されています。';
+$lang['i_funcnmail']           = '<b>注：</b>PHPの mail 関数が利用不能になっています。 %s この状況が続く場合は、<a href="https://www.dokuwiki.org/plugin:smtp">smtpプラグイン</a>をインストールして解決する事も出来ます。';
 $lang['i_phpver']              = 'PHPのバージョン <code>%s</code> が必要なバージョン <code>%s</code> より以前のものです。PHPのアップグレードが必要です。';
+$lang['i_mbfuncoverload']      = 'DokuWiki を実行する php.ini ファイルの mbstring.func_overload は無効にして下さい。';
+$lang['i_urandom']             = 'DokuWikiは、Cookieに対して暗号的に安全な番号を作成できません。<code>/dev/urandom</code>に対する適切なアクセスについて、php.iniの設定 open_basedir を確認する事をお勧めします。';
 $lang['i_permfail']            = '<code>%s</code> に書き込みできません。このディレクトリの権限を確認して下さい。';
 $lang['i_confexists']          = '<code>%s</code> は既に存在します';
 $lang['i_writeerr']            = '<code>%s</code> を作成できません。ディレクトリとファイルの権限を確認し、それらを手動で作成する必要があります。';
 $lang['i_badhash']             = 'dokuwiki.php が認識できないか、編集されています（hash=<code>%s</code>）';
 $lang['i_badval']              = '<code>%s</code> - 正しくない、もしくは値が空です';
-$lang['i_success']             = '設定ファイルは正しく作成されました。<a href="doku.php?id=wiki:welcome">作成した DokuWiki</a>を使用するには install.php を削除してください。';
+$lang['i_success']             = '設定ファイルは正しく作成されました。install.phpは、もう削除しても構いません。引き続き、<a href="doku.php?id=wiki:welcome">作成したDokuWiki</a>をご利用下さい。';
 $lang['i_failure']             = '設定ファイルの作成中にエラーが発生しました。<a href="doku.php?id=wiki:welcome">作成した DokuWiki</a>を使用する前に、それらの問題を手動で修正する必要があります。';
 $lang['i_policy']              = 'ACL初期設定';
 $lang['i_pol0']                = 'オープン Wiki（全ての人に、閲覧・書き込み・アップロードを許可）';
 $lang['i_pol1']                = 'パブリック Wiki（閲覧は全ての人が可能、書き込み・アップロードは登録ユーザーのみ）';
-$lang['i_pol2']                = 'クローズド Wiki (登録ユーザーにのみ使用を許可)';
-$lang['i_allowreg']            = 'ユーザ自身で登録可能';
+$lang['i_pol2']                = 'クローズド Wiki（登録ユーザーにのみ、閲覧・書き込み・アップロードを許可）';
+$lang['i_allowreg']            = '訪問者自身でユーザー登録機能を使えるようにする';
 $lang['i_retry']               = '再試行';
 $lang['i_license']             = 'あなたが作成したコンテンツが属するライセンスを選択してください：';
 $lang['i_license_none']        = 'ライセンス情報を表示しません。';
 $lang['i_pop_field']           = 'Dokuwiki の内容の向上に協力して下さい：';
-$lang['i_pop_label']           = '月に一回、DokuWikiの開発者に匿名の使用データを送信します。';
-$lang['recent_global']         = '現在、<b>%s</b> 名前空間内の変更点を閲覧中です。<a href="%s">Wiki全体の最近の変更点の確認</a>もできます。';
+$lang['i_pop_label']           = '月に一回、DokuWikiの開発者に匿名の使用データを送信する';
+$lang['recent_global']         = '現在、名前空間 <b>%s</b> 内の変更を閲覧中です。<a href="%s">Wiki全体の最近の変更の確認</a>もできます。';
 $lang['years']                 = '%d年前';
 $lang['months']                = '%dカ月前';
 $lang['weeks']                 = '%d週間前';
@@ -324,15 +348,21 @@ $lang['media_files']           = '%s 内のファイル';
 $lang['media_upload']          = '%s にアップロード';
 $lang['media_search']          = '%s 内で検索';
 $lang['media_view']            = '%s';
-$lang['media_viewold']         = '%s at %s';
+$lang['media_viewold']         = '%2$s に %1$s';
 $lang['media_edit']            = '%s を編集';
 $lang['media_history']         = '%s の履歴';
 $lang['media_meta_edited']     = 'メタデータが編集されました';
-$lang['media_perm_read']       = 'ファイルを閲覧する権限がありません。';
-$lang['media_perm_upload']     = 'ファイルをアップロードする権限がありません。';
+$lang['media_perm_read']       = '申し訳ありませんが、ファイルを閲覧する権限がありません。';
+$lang['media_perm_upload']     = '申し訳ありませんが、ファイルをアップロードする権限がありません。';
 $lang['media_update']          = '新しいバージョンをアップロード';
 $lang['media_restore']         = 'このバージョンを復元';
+$lang['media_acl_warning']     = '閲覧権限の無いページや非表示ページは表示されないので、このリストは完全でない場合があります。';
+$lang['email_fail']            = 'PHPの mail() が欠落しているか無効になっています。次のEメールが送信されませんでした。';
 $lang['currentns']             = '現在の名前空間';
 $lang['searchresult']          = '検索結果';
 $lang['plainhtml']             = 'プレーンHTML';
 $lang['wikimarkup']            = 'Wikiマークアップ';
+$lang['page_nonexist_rev']     = '指定ページ %s はありません。このリンク <a href="%s">%s</a> から作成できます。';
+$lang['unable_to_parse_date']  = 'パラメータ "%s" を処理できません。';
+$lang['email_signature_text']  = 'このメールは次のDokuWikiより自動的に送信されています。
+@DOKUWIKIURL@';
