@@ -1,4 +1,5 @@
 <?php
+
 /**
  * Utilities for handling pagenames
  *
@@ -7,6 +8,11 @@
  * @todo       Combine similar functions like {wiki,media,meta}FN()
  */
 
+use dokuwiki\ChangeLog\MediaChangeLog;
+use dokuwiki\ChangeLog\PageChangeLog;
+use dokuwiki\File\MediaResolver;
+use dokuwiki\File\PageResolver;
+
 /**
  * Fetch the an ID from request
  *
@@ -22,7 +28,8 @@
  * @param bool   $clean  if true, ID is cleaned
  * @return string
  */
-function getID($param='id',$clean=true){
+function getID($param = 'id', $clean = true)
+{
     /** @var Input $INPUT */
     global $INPUT;
     global $conf;
@@ -31,67 +38,69 @@ function getID($param='id',$clean=true){
     $id = $INPUT->str($param);
 
     //construct page id from request URI
-    if(empty($id) && $conf['userewrite'] == 2){
+    if (empty($id) && $conf['userewrite'] == 2) {
         $request = $INPUT->server->str('REQUEST_URI');
         $script = '';
 
         //get the script URL
-        if($conf['basedir']){
+        if ($conf['basedir']) {
             $relpath = '';
-            if($param != 'id') {
+            if ($param != 'id') {
                 $relpath = 'lib/exe/';
             }
-            $script = $conf['basedir'].$relpath.utf8_basename($INPUT->server->str('SCRIPT_FILENAME'));
-
-        }elseif($INPUT->server->str('PATH_INFO')){
+            $script = $conf['basedir'] . $relpath .
+                \dokuwiki\Utf8\PhpString::basename($INPUT->server->str('SCRIPT_FILENAME'));
+        } elseif ($INPUT->server->str('PATH_INFO')) {
             $request = $INPUT->server->str('PATH_INFO');
-        }elseif($INPUT->server->str('SCRIPT_NAME')){
+        } elseif ($INPUT->server->str('SCRIPT_NAME')) {
             $script = $INPUT->server->str('SCRIPT_NAME');
-        }elseif($INPUT->server->str('DOCUMENT_ROOT') && $INPUT->server->str('SCRIPT_FILENAME')){
-            $script = preg_replace ('/^'.preg_quote($INPUT->server->str('DOCUMENT_ROOT'),'/').'/','',
-                    $INPUT->server->str('SCRIPT_FILENAME'));
-            $script = '/'.$script;
+        } elseif ($INPUT->server->str('DOCUMENT_ROOT') && $INPUT->server->str('SCRIPT_FILENAME')) {
+            $script = preg_replace(
+                '/^' . preg_quote($INPUT->server->str('DOCUMENT_ROOT'), '/') . '/',
+                '',
+                $INPUT->server->str('SCRIPT_FILENAME')
+            );
+            $script = '/' . $script;
         }
 
         //clean script and request (fixes a windows problem)
-        $script  = preg_replace('/\/\/+/','/',$script);
-        $request = preg_replace('/\/\/+/','/',$request);
+        $script  = preg_replace('/\/\/+/', '/', $script);
+        $request = preg_replace('/\/\/+/', '/', $request);
 
         //remove script URL and Querystring to gain the id
-        if(preg_match('/^'.preg_quote($script,'/').'(.*)/',$request, $match)){
-            $id = preg_replace ('/\?.*/','',$match[1]);
+        if (preg_match('/^' . preg_quote($script, '/') . '(.*)/', $request, $match)) {
+            $id = preg_replace('/\?.*/', '', $match[1]);
         }
         $id = urldecode($id);
         //strip leading slashes
-        $id = preg_replace('!^/+!','',$id);
+        $id = preg_replace('!^/+!', '', $id);
     }
 
     // Namespace autolinking from URL
-    if(substr($id,-1) == ':' || ($conf['useslash'] && substr($id,-1) == '/')){
-        if(page_exists($id.$conf['start'])){
+    if (substr($id, -1) == ':' || ($conf['useslash'] && substr($id, -1) == '/')) {
+        if (page_exists($id . $conf['start'])) {
             // start page inside namespace
-            $id = $id.$conf['start'];
-        }elseif(page_exists($id.noNS(cleanID($id)))){
+            $id = $id . $conf['start'];
+        } elseif (page_exists($id . noNS(cleanID($id)))) {
             // page named like the NS inside the NS
-            $id = $id.noNS(cleanID($id));
-        }elseif(page_exists($id)){
+            $id = $id . noNS(cleanID($id));
+        } elseif (page_exists($id)) {
             // page like namespace exists
-            $id = substr($id,0,-1);
-        }else{
+            $id = substr($id, 0, -1);
+        } else {
             // fall back to default
-            $id = $id.$conf['start'];
+            $id = $id . $conf['start'];
         }
         if (isset($ACT) && $ACT === 'show') {
             $urlParameters = $_GET;
             if (isset($urlParameters['id'])) {
                 unset($urlParameters['id']);
             }
-            send_redirect(wl($id,$urlParameters,true));
+            send_redirect(wl($id, $urlParameters, true, '&'));
         }
     }
-
-    if($clean) $id = cleanID($id);
-    if(empty($id) && $param=='id') $id = $conf['start'];
+    if ($clean) $id = cleanID($id);
+    if ($id === '' && $param == 'id') $id = $conf['start'];
 
     return $id;
 }
@@ -108,7 +117,8 @@ function getID($param='id',$clean=true){
  * @param  boolean $ascii     Force ASCII
  * @return string cleaned id
  */
-function cleanID($raw_id,$ascii=false){
+function cleanID($raw_id, $ascii = false)
+{
     global $conf;
     static $sepcharpat = null;
 
@@ -121,33 +131,33 @@ function cleanID($raw_id,$ascii=false){
     }
 
     $sepchar = $conf['sepchar'];
-    if($sepcharpat == null) // build string only once to save clock cycles
-        $sepcharpat = '#\\'.$sepchar.'+#';
+    if ($sepcharpat == null) // build string only once to save clock cycles
+        $sepcharpat = '#\\' . $sepchar . '+#';
 
     $id = trim((string)$raw_id);
-    $id = utf8_strtolower($id);
+    $id = \dokuwiki\Utf8\PhpString::strtolower($id);
 
     //alternative namespace seperator
-    if($conf['useslash']){
-        $id = strtr($id,';/','::');
-    }else{
-        $id = strtr($id,';/',':'.$sepchar);
+    if ($conf['useslash']) {
+        $id = strtr($id, ';/', '::');
+    } else {
+        $id = strtr($id, ';/', ':' . $sepchar);
     }
 
-    if($conf['deaccent'] == 2 || $ascii) $id = utf8_romanize($id);
-    if($conf['deaccent'] || $ascii) $id = utf8_deaccent($id,-1);
+    if ($conf['deaccent'] == 2 || $ascii) $id = \dokuwiki\Utf8\Clean::romanize($id);
+    if ($conf['deaccent'] || $ascii) $id = \dokuwiki\Utf8\Clean::deaccent($id, -1);
 
     //remove specials
-    $id = utf8_stripspecials($id,$sepchar,'\*');
+    $id = \dokuwiki\Utf8\Clean::stripspecials($id, $sepchar, '\*');
 
-    if($ascii) $id = utf8_strip($id);
+    if ($ascii) $id = \dokuwiki\Utf8\Clean::strip($id);
 
     //clean up
-    $id = preg_replace($sepcharpat,$sepchar,$id);
-    $id = preg_replace('#:+#',':',$id);
-    $id = trim($id,':._-');
-    $id = preg_replace('#:[:\._\-]+#',':',$id);
-    $id = preg_replace('#[:\._\-]+:#',':',$id);
+    $id = preg_replace($sepcharpat, $sepchar, $id);
+    $id = preg_replace('#:+#', ':', $id);
+    $id = trim($id, ':._-');
+    $id = preg_replace('#:[:\._\-]+#', ':', $id);
+    $id = preg_replace('#[:\._\-]+:#', ':', $id);
 
     if (!$ascii) $cache[(string)$raw_id] = $id;
     return($id);
@@ -161,10 +171,11 @@ function cleanID($raw_id,$ascii=false){
  * @param string $id
  * @return string|false the namespace part or false if the given ID has no namespace (root)
  */
-function getNS($id){
-    $pos = strrpos((string)$id,':');
-    if($pos!==false){
-        return substr((string)$id,0,$pos);
+function getNS($id)
+{
+    $pos = strrpos((string)$id, ':');
+    if ($pos !== false) {
+        return substr((string)$id, 0, $pos);
     }
     return false;
 }
@@ -177,10 +188,11 @@ function getNS($id){
  * @param string $id
  * @return string
  */
-function noNS($id) {
+function noNS($id)
+{
     $pos = strrpos($id, ':');
-    if ($pos!==false) {
-        return substr($id, $pos+1);
+    if ($pos !== false) {
+        return substr($id, $pos + 1);
     } else {
         return $id;
     }
@@ -194,7 +206,8 @@ function noNS($id) {
  * @param string $id
  * @return string
  */
-function curNS($id) {
+function curNS($id)
+{
     return noNS(getNS($id));
 }
 
@@ -206,13 +219,14 @@ function curNS($id) {
  * @param string $id
  * @return string
  */
-function noNSorNS($id) {
+function noNSorNS($id)
+{
     global $conf;
 
     $p = noNS($id);
-    if ($p == $conf['start'] || $p == false) {
+    if ($p === $conf['start'] || $p === false || $p === '') {
         $p = curNS($id);
-        if ($p == false) {
+        if ($p === false || $p === '') {
             return $conf['start'];
         }
     }
@@ -223,30 +237,32 @@ function noNSorNS($id) {
  * Creates a XHTML valid linkid from a given headline title
  *
  * @param string  $title   The headline title
- * @param array|bool   $check   Existing IDs (title => number)
+ * @param array|bool   $check   Existing IDs
  * @return string the title
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function sectionID($title,&$check) {
-    $title = str_replace(array(':','.'),'',cleanID($title));
-    $new = ltrim($title,'0123456789_-');
-    if(empty($new)){
-        $title = 'section'.preg_replace('/[^0-9]+/','',$title); //keep numbers from headline
-    }else{
+function sectionID($title, &$check)
+{
+    $title = str_replace(array(':','.'), '', cleanID($title));
+    $new = ltrim($title, '0123456789_-');
+    if (empty($new)) {
+        $title = 'section' . preg_replace('/[^0-9]+/', '', $title); //keep numbers from headline
+    } else {
         $title = $new;
     }
 
-    if(is_array($check)){
-        // make sure tiles are unique
-        if (!array_key_exists ($title,$check)) {
-            $check[$title] = 0;
-        } else {
-            $title .= ++ $check[$title];
+    if (is_array($check)) {
+        $suffix = 0;
+        $candidateTitle = $title;
+        while (in_array($candidateTitle, $check)) {
+            $candidateTitle = $title . ++$suffix;
         }
+        $check [] = $candidateTitle;
+        return $candidateTitle;
+    } else {
+        return $title;
     }
-
-    return $title;
 }
 
 /**
@@ -262,14 +278,38 @@ function sectionID($title,&$check) {
  * @param bool $date_at
  * @return bool exists?
  */
-function page_exists($id,$rev='',$clean=true, $date_at=false) {
-    if($rev !== '' && $date_at) {
+function page_exists($id, $rev = '', $clean = true, $date_at = false)
+{
+    $id = (explode('#', $id, 2))[0]; // #3608
+
+    if ($rev !== '' && $date_at) {
         $pagelog = new PageChangeLog($id);
         $pagelog_rev = $pagelog->getLastRevisionAt($rev);
-        if($pagelog_rev !== false)
+        if ($pagelog_rev !== false)
             $rev = $pagelog_rev;
     }
-    return file_exists(wikiFN($id,$rev,$clean));
+    return file_exists(wikiFN($id, $rev, $clean));
+}
+
+/**
+ * Media existence check
+ *
+ * @param string $id page id
+ * @param string|int $rev empty or revision timestamp
+ * @param bool $clean flag indicating that $id should be cleaned (see mediaFN as well)
+ * @param bool $date_at
+ * @return bool exists?
+ */
+function media_exists($id, $rev = '', $clean = true, $date_at = false)
+{
+    if ($rev !== '' && $date_at) {
+        $changeLog = new MediaChangeLog($id);
+        $changelog_rev = $changeLog->getLastRevisionAt($rev);
+        if ($changelog_rev !== false) {
+            $rev = $changelog_rev;
+        }
+    }
+    return file_exists(mediaFN($id, $rev, $clean));
 }
 
 /**
@@ -285,7 +325,8 @@ function page_exists($id,$rev='',$clean=true, $date_at=false) {
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function wikiFN($raw_id,$rev='',$clean=true){
+function wikiFN($raw_id, $rev = '', $clean = true)
+{
     global $conf;
 
     global $cache_wikifn;
@@ -294,30 +335,32 @@ function wikiFN($raw_id,$rev='',$clean=true){
     $id = $raw_id;
 
     if ($clean) $id = cleanID($id);
-    $id = str_replace(':','/',$id);
+    $id = str_replace(':', '/', $id);
 
     if (isset($cache[$id]) && isset($cache[$id][$rev])) {
         return $cache[$id][$rev];
     }
 
-    if(empty($rev)){
-        $fn = $conf['datadir'].'/'.utf8_encodeFN($id).'.txt';
-    }else{
-        $fn = $conf['olddir'].'/'.utf8_encodeFN($id).'.'.$rev.'.txt';
-        if($conf['compression']){
+    if (empty($rev)) {
+        $fn = $conf['datadir'] . '/' . utf8_encodeFN($id) . '.txt';
+    } else {
+        $fn = $conf['olddir'] . '/' . utf8_encodeFN($id) . '.' . $rev . '.txt';
+        if ($conf['compression']) {
             //test for extensions here, we want to read both compressions
-            if (file_exists($fn . '.gz')){
+            if (file_exists($fn . '.gz')) {
                 $fn .= '.gz';
-            }else if(file_exists($fn . '.bz2')){
+            } elseif (file_exists($fn . '.bz2')) {
                 $fn .= '.bz2';
-            }else{
+            } else {
                 //file doesnt exist yet, so we take the configured extension
                 $fn .= '.' . $conf['compression'];
             }
         }
     }
 
-    if (!isset($cache[$id])) { $cache[$id] = array(); }
+    if (!isset($cache[$id])) {
+        $cache[$id] = array();
+    }
     $cache[$id][$rev] = $fn;
     return $fn;
 }
@@ -330,9 +373,10 @@ function wikiFN($raw_id,$rev='',$clean=true){
  * @param string $id page id
  * @return string full path
  */
-function wikiLockFN($id) {
+function wikiLockFN($id)
+{
     global $conf;
-    return $conf['lockdir'].'/'.md5(cleanID($id)).'.lock';
+    return $conf['lockdir'] . '/' . md5(cleanID($id)) . '.lock';
 }
 
 
@@ -345,11 +389,12 @@ function wikiLockFN($id) {
  * @param string $ext  file extension
  * @return string full path
  */
-function metaFN($id,$ext){
+function metaFN($id, $ext)
+{
     global $conf;
     $id = cleanID($id);
-    $id = str_replace(':','/',$id);
-    $fn = $conf['metadir'].'/'.utf8_encodeFN($id).$ext;
+    $id = str_replace(':', '/', $id);
+    $fn = $conf['metadir'] . '/' . utf8_encodeFN($id) . $ext;
     return $fn;
 }
 
@@ -362,11 +407,12 @@ function metaFN($id,$ext){
  * @param string $ext  extension of media
  * @return string
  */
-function mediaMetaFN($id,$ext){
+function mediaMetaFN($id, $ext)
+{
     global $conf;
     $id = cleanID($id);
-    $id = str_replace(':','/',$id);
-    $fn = $conf['mediametadir'].'/'.utf8_encodeFN($id).$ext;
+    $id = str_replace(':', '/', $id);
+    $fn = $conf['mediametadir'] . '/' . utf8_encodeFN($id) . $ext;
     return $fn;
 }
 
@@ -379,11 +425,12 @@ function mediaMetaFN($id,$ext){
  * @param string $id page id
  * @return array
  */
-function metaFiles($id){
+function metaFiles($id)
+{
     $basename = metaFN($id, '');
-    $files    = glob($basename.'.*', GLOB_MARK);
+    $files    = glob($basename . '.*', GLOB_MARK);
     // filter files like foo.bar.meta when $id == 'foo'
-    return    $files ? preg_grep('/^'.preg_quote($basename, '/').'\.[^.\/]*$/u', $files) : array();
+    return    $files ? preg_grep('/^' . preg_quote($basename, '/') . '\.[^.\/]*$/u', $files) : array();
 }
 
 /**
@@ -400,16 +447,17 @@ function metaFiles($id){
  *
  * @return string full path
  */
-function mediaFN($id, $rev='', $clean=true){
+function mediaFN($id, $rev = '', $clean = true)
+{
     global $conf;
     if ($clean) $id = cleanID($id);
-    $id = str_replace(':','/',$id);
-    if(empty($rev)){
-        $fn = $conf['mediadir'].'/'.utf8_encodeFN($id);
-    }else{
+    $id = str_replace(':', '/', $id);
+    if (empty($rev)) {
+        $fn = $conf['mediadir'] . '/' . utf8_encodeFN($id);
+    } else {
         $ext = mimetype($id);
-        $name = substr($id,0, -1*strlen($ext[0])-1);
-        $fn = $conf['mediaolddir'].'/'.utf8_encodeFN($name .'.'.( (int) $rev ).'.'.$ext[0]);
+        $name = substr($id, 0, -1 * strlen($ext[0]) - 1);
+        $fn = $conf['mediaolddir'] . '/' . utf8_encodeFN($name . '.' . ( (int) $rev ) . '.' . $ext[0]);
     }
     return $fn;
 }
@@ -424,14 +472,15 @@ function mediaFN($id, $rev='', $clean=true){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function localeFN($id,$ext='txt'){
+function localeFN($id, $ext = 'txt')
+{
     global $conf;
-    $file = DOKU_CONF.'lang/'.$conf['lang'].'/'.$id.'.'.$ext;
-    if(!file_exists($file)){
-        $file = DOKU_INC.'inc/lang/'.$conf['lang'].'/'.$id.'.'.$ext;
-        if(!file_exists($file)){
+    $file = DOKU_CONF . 'lang/' . $conf['lang'] . '/' . $id . '.' . $ext;
+    if (!file_exists($file)) {
+        $file = DOKU_INC . 'inc/lang/' . $conf['lang'] . '/' . $id . '.' . $ext;
+        if (!file_exists($file)) {
             //fall back to english
-            $file = DOKU_INC.'inc/lang/en/'.$id.'.'.$ext;
+            $file = DOKU_INC . 'inc/lang/en/' . $id . '.' . $ext;
         }
     }
     return $file;
@@ -446,32 +495,33 @@ function localeFN($id,$ext='txt'){
  * Partyly based on a cleanPath function found at
  * http://php.net/manual/en/function.realpath.php#57016
  *
- * @author <bart at mediawave dot nl>
- *
+ * @deprecated 2020-09-30
  * @param string $ns     namespace which is context of id
  * @param string $id     relative id
  * @param bool   $clean  flag indicating that id should be cleaned
  * @return string
  */
-function resolve_id($ns,$id,$clean=true){
+function resolve_id($ns, $id, $clean = true)
+{
     global $conf;
+    dbg_deprecated(\dokuwiki\File\Resolver::class . ' and its children');
 
     // some pre cleaning for useslash:
-    if($conf['useslash']) $id = str_replace('/',':',$id);
+    if ($conf['useslash']) $id = str_replace('/', ':', $id);
 
     // if the id starts with a dot we need to handle the
     // relative stuff
-    if($id && $id{0} == '.'){
+    if ($id && $id[0] == '.') {
         // normalize initial dots without a colon
-        $id = preg_replace('/^(\.+)(?=[^:\.])/','\1:',$id);
+        $id = preg_replace('/^((\.+:)*)(\.+)(?=[^:\.])/', '\1\3:', $id);
         // prepend the current namespace
-        $id = $ns.':'.$id;
+        $id = $ns . ':' . $id;
 
         // cleanup relatives
         $result = array();
         $pathA  = explode(':', $id);
         if (!$pathA[0]) $result[] = '';
-        foreach ($pathA AS $key => $dir) {
+        foreach ($pathA as $key => $dir) {
             if ($dir == '..') {
                 if (end($result) == '..') {
                     $result[] = '..';
@@ -484,122 +534,57 @@ function resolve_id($ns,$id,$clean=true){
         }
         if (!end($pathA)) $result[] = '';
         $id = implode(':', $result);
-    }elseif($ns !== false && strpos($id,':') === false){
+    } elseif ($ns !== false && strpos($id, ':') === false) {
         //if link contains no namespace. add current namespace (if any)
-        $id = $ns.':'.$id;
+        $id = $ns . ':' . $id;
     }
 
-    if($clean) $id = cleanID($id);
+    if ($clean) $id = cleanID($id);
     return $id;
 }
 
 /**
  * Returns a full media id
  *
- * @author Andreas Gohr <andi@splitbrain.org>
- *
  * @param string $ns namespace which is context of id
- * @param string &$page (reference) relative media id, updated to resolved id
+ * @param string &$media (reference) relative media id, updated to resolved id
  * @param bool &$exists (reference) updated with existance of media
  * @param int|string $rev
  * @param bool $date_at
+ * @deprecated 2020-09-30
  */
-function resolve_mediaid($ns,&$page,&$exists,$rev='',$date_at=false){
-    $page   = resolve_id($ns,$page);
-    if($rev !== '' &&  $date_at){
-        $medialog = new MediaChangeLog($page);
-        $medialog_rev = $medialog->getLastRevisionAt($rev);
-        if($medialog_rev !== false) {
-            $rev = $medialog_rev;
-        }
-    }
-
-    $file   = mediaFN($page,$rev);
-    $exists = file_exists($file);
+function resolve_mediaid($ns, &$media, &$exists, $rev = '', $date_at = false)
+{
+    dbg_deprecated(MediaResolver::class);
+    $resolver = new MediaResolver("$ns:deprecated");
+    $media = $resolver->resolveId($media, $rev, $date_at);
+    $exists = media_exists($media, $rev, false, $date_at);
 }
 
 /**
  * Returns a full page id
  *
- * @author Andreas Gohr <andi@splitbrain.org>
- *
+ * @deprecated 2020-09-30
  * @param string $ns namespace which is context of id
  * @param string &$page (reference) relative page id, updated to resolved id
  * @param bool &$exists (reference) updated with existance of media
  * @param string $rev
  * @param bool $date_at
  */
-function resolve_pageid($ns,&$page,&$exists,$rev='',$date_at=false ){
-    global $conf;
+function resolve_pageid($ns, &$page, &$exists, $rev = '', $date_at = false)
+{
+    dbg_deprecated(PageResolver::class);
+
     global $ID;
-    $exists = false;
-
-    //empty address should point to current page
-    if ($page === "") {
-        $page = $ID;
-    }
-
-    //keep hashlink if exists then clean both parts
-    if (strpos($page,'#')) {
-        list($page,$hash) = explode('#',$page,2);
+    if (getNS($ID) == $ns) {
+        $context = $ID; // this is usually the case
     } else {
-        $hash = '';
-    }
-    $hash = cleanID($hash);
-    $page = resolve_id($ns,$page,false); // resolve but don't clean, yet
-
-    // get filename (calls clean itself)
-    if($rev !== '' && $date_at) {
-        $pagelog = new PageChangeLog($page);
-        $pagelog_rev = $pagelog->getLastRevisionAt($rev);
-        if($pagelog_rev !== false)//something found
-           $rev  = $pagelog_rev;
-    }
-    $file = wikiFN($page,$rev);
-
-    // if ends with colon or slash we have a namespace link
-    if(in_array(substr($page,-1), array(':', ';')) ||
-       ($conf['useslash'] && substr($page,-1) == '/')){
-        if(page_exists($page.$conf['start'],$rev,true,$date_at)){
-            // start page inside namespace
-            $page = $page.$conf['start'];
-            $exists = true;
-        }elseif(page_exists($page.noNS(cleanID($page)),$rev,true,$date_at)){
-            // page named like the NS inside the NS
-            $page = $page.noNS(cleanID($page));
-            $exists = true;
-        }elseif(page_exists($page,$rev,true,$date_at)){
-            // page like namespace exists
-            $page = $page;
-            $exists = true;
-        }else{
-            // fall back to default
-            $page = $page.$conf['start'];
-        }
-    }else{
-        //check alternative plural/nonplural form
-        if(!file_exists($file)){
-            if( $conf['autoplural'] ){
-                if(substr($page,-1) == 's'){
-                    $try = substr($page,0,-1);
-                }else{
-                    $try = $page.'s';
-                }
-                if(page_exists($try,$rev,true,$date_at)){
-                    $page   = $try;
-                    $exists = true;
-                }
-            }
-        }else{
-            $exists = true;
-        }
+        $context = "$ns:deprecated"; // only used when a different context namespace was given
     }
 
-    // now make sure we have a clean page
-    $page = cleanID($page);
-
-    //add hash if any
-    if(!empty($hash)) $page .= '#'.$hash;
+    $resolver = new PageResolver($context);
+    $page = $resolver->resolveId($page, $rev, $date_at);
+    $exists = page_exists($page, $rev, false, $date_at);
 }
 
 /**
@@ -613,10 +598,11 @@ function resolve_pageid($ns,&$page,&$exists,$rev='',$date_at=false ){
  * @param string $ext   This is appended to the filename if given
  * @return string       The filename of the cachefile
  */
-function getCacheName($data,$ext=''){
+function getCacheName($data, $ext = '')
+{
     global $conf;
     $md5  = md5($data);
-    $file = $conf['cachedir'].'/'.$md5{0}.'/'.$md5.$ext;
+    $file = $conf['cachedir'] . '/' . $md5[0] . '/' . $md5 . $ext;
     io_makeFileDir($file);
     return $file;
 }
@@ -629,12 +615,13 @@ function getCacheName($data,$ext=''){
  * @param string $id page id
  * @return bool
  */
-function isHiddenPage($id){
+function isHiddenPage($id)
+{
     $data = array(
         'id' => $id,
         'hidden' => false
     );
-    trigger_event('PAGEUTILS_ID_HIDEPAGE', $data, '_isHiddenPage');
+    \dokuwiki\Extension\Event::createAndTrigger('PAGEUTILS_ID_HIDEPAGE', $data, '_isHiddenPage');
     return $data['hidden'];
 }
 
@@ -643,15 +630,16 @@ function isHiddenPage($id){
  *
  * @param array $data event data    - see isHiddenPage()
  */
-function _isHiddenPage(&$data) {
+function _isHiddenPage(&$data)
+{
     global $conf;
     global $ACT;
 
     if ($data['hidden']) return;
-    if(empty($conf['hidepages'])) return;
-    if($ACT == 'admin') return;
+    if (empty($conf['hidepages'])) return;
+    if ($ACT == 'admin') return;
 
-    if(preg_match('/'.$conf['hidepages'].'/ui',':'.$data['id'])){
+    if (preg_match('/' . $conf['hidepages'] . '/ui', ':' . $data['id'])) {
         $data['hidden'] = true;
     }
 }
@@ -664,7 +652,8 @@ function _isHiddenPage(&$data) {
  * @param string $id page id
  * @return bool
  */
-function isVisiblePage($id){
+function isVisiblePage($id)
+{
     return !isHiddenPage($id);
 }
 
@@ -679,7 +668,8 @@ function isVisiblePage($id){
  * @param string $id page id
  * @return string
  */
-function prettyprint_id($id) {
+function prettyprint_id($id)
+{
     if (!$id || $id === ':') {
         return '*';
     }
@@ -706,20 +696,21 @@ function prettyprint_id($id) {
  * @param bool   $safe if true, only encoded when non ASCII characters detected
  * @return string
  */
-function utf8_encodeFN($file,$safe=true){
+function utf8_encodeFN($file, $safe = true)
+{
     global $conf;
-    if($conf['fnencode'] == 'utf-8') return $file;
+    if ($conf['fnencode'] == 'utf-8') return $file;
 
-    if($safe && preg_match('#^[a-zA-Z0-9/_\-\.%]+$#',$file)){
+    if ($safe && preg_match('#^[a-zA-Z0-9/_\-\.%]+$#', $file)) {
         return $file;
     }
 
-    if($conf['fnencode'] == 'safe'){
+    if ($conf['fnencode'] == 'safe') {
         return SafeFN::encode($file);
     }
 
     $file = urlencode($file);
-    $file = str_replace('%2F','/',$file);
+    $file = str_replace('%2F', '/', $file);
     return $file;
 }
 
@@ -734,11 +725,12 @@ function utf8_encodeFN($file,$safe=true){
  * @param string $file file name
  * @return string
  */
-function utf8_decodeFN($file){
+function utf8_decodeFN($file)
+{
     global $conf;
-    if($conf['fnencode'] == 'utf-8') return $file;
+    if ($conf['fnencode'] == 'utf-8') return $file;
 
-    if($conf['fnencode'] == 'safe'){
+    if ($conf['fnencode'] == 'safe') {
         return SafeFN::decode($file);
     }
 
@@ -758,18 +750,19 @@ function utf8_decodeFN($file){
  * @param bool $useacl only return pages readable by the current user, false to ignore ACLs
  * @return false|string the full page id of the found page, false if any
  */
-function page_findnearest($page, $useacl = true){
-    if (!$page) return false;
+function page_findnearest($page, $useacl = true)
+{
+    if ((string) $page === '') return false;
     global $ID;
 
     $ns = $ID;
     do {
         $ns = getNS($ns);
         $pageid = cleanID("$ns:$page");
-        if(page_exists($pageid) && (!$useacl || auth_quickaclcheck($pageid) >= AUTH_READ)){
+        if (page_exists($pageid) && (!$useacl || auth_quickaclcheck($pageid) >= AUTH_READ)) {
             return $pageid;
         }
-    } while($ns);
+    } while ($ns !== false);
 
     return false;
 }
