@@ -30,8 +30,6 @@ $lang['_links']                = 'लिंक सेटिंग';
 $lang['_media']                = 'दृक्श्राव्य माध्यम सेटिंग';
 $lang['_advanced']             = 'सविस्तर सेटिंग';
 $lang['_network']              = 'नेटवर्क सेटिंग';
-$lang['_plugin_sufix']         = 'प्लगिन सेटिंग';
-$lang['_template_sufix']       = 'टेम्पलेट ( नमुना ) सेटिंग';
 $lang['_msg_setting_undefined'] = 'सेटिंगविषयी उप-डेटा उपलब्ध नाही.';
 $lang['_msg_setting_no_class'] = 'सेटिंगचा क्लास उपलब्ध नाही';
 $lang['_msg_setting_no_default'] = 'आपोआप किम्मत नाही';
@@ -52,7 +50,7 @@ $lang['youarehere']            = 'प्रतवार ब्रेडक्र
 $lang['typography']            = 'अनवधानाने झालेल्या चुका बदला';
 $lang['htmlok']                = 'अंतर्गत HTML टाकायची परवानगी असू दे';
 $lang['phpok']                 = 'अंतर्गत PHP टाकायची परवानगी असू दे';
-$lang['dformat']               = 'दिनांकाची पद्धत ( PHP चं <a href="http://www.php.net/strftime">strftime</a> हे फंक्शन पाहा )';
+$lang['dformat']               = 'दिनांकाची पद्धत ( PHP चं <a href="http://php.net/strftime">strftime</a> हे फंक्शन पाहा )';
 $lang['signature']             = 'हस्ताक्षर';
 $lang['toptoclevel']           = 'अनुक्रमणिकेची सर्वोच्च पातळी';
 $lang['tocminheads']           = 'कमीत कमी किती शीर्षके असल्यास अनुक्रमणिका बनवावी';
@@ -62,7 +60,6 @@ $lang['camelcase']             = 'लिंकसाठी कॅमलकेस
 $lang['deaccent']              = 'सरळ्सोट पृष्ठ नाम';
 $lang['useheading']            = 'पहिलं शीर्षक पृष्ठ नाम म्हणुन वापरा';
 $lang['refcheck']              = 'दृक्श्राव्य माध्यमाचा संदर्भ तपासा';
-$lang['refshow']               = 'दृक्श्राव्य माध्यामाचे संदर्भ दाखवण्याची संख्या';
 $lang['allowdebug']            = 'डिबगची परवानगी <b> गरज नसल्यास बंद ठेवा !</b>';
 $lang['usewordblock']          = 'भंकस मजकूर थोपवण्यासाठी शब्दसमुह वापरा';
 $lang['indexdelay']            = 'सूचीकरणापूर्वीचा अवकाश ( सेकंदात )';
@@ -86,8 +83,6 @@ $lang['disableactions_other']  = 'इतर क्रिया ( स्वल्
 $lang['sneaky_index']          = 'सूची दृश्यामधे डिफॉल्ट स्वरूपात डॉक्युविकी सगळे नेमस्पेस दाखवते. हा पर्याय चालू केल्यास सदस्याला वाचण्याची परवानगी नसलेले नेमस्पेस दिसणार नाहीत. यामुळे परवानगी असलेले उप - नेमस्पेस न दिसण्याची शक्यता आहे. यामुळे काही विशिष्ठ ACL सेटिंगसाठी सूची वापरता येण्यासारखी राहणार नाही.';
 $lang['auth_security_timeout'] = 'अधिकृत करण्याच्या प्रक्रियेची कालमर्यादा';
 $lang['securecookie']          = 'HTTPS वापरून सेट केलेले कूकीज ब्राउजरने HTTPS द्वाराच पाठवले पाहिजेत का? जर तुमच्या विकीचं फ़क्त लॉगिन पानच SSL वापरून सुरक्षित केलं असेल व पानांचं ब्राउजिंग असुरक्षित असेल तर हा पर्याय चालू करू नका.';
-$lang['xmlrpc']                = 'XML-RPC इंटरफेस चालू/बंद करा';
-$lang['xmlrpcuser']            = 'XML-RPC सुविधा फ़क्त इथे स्वल्पविरामाने अलग करून दिलेल्या गट किंवा वापरकर्त्याला उपलब्ध आहेत. सर्वाना ही सुविधा देण्यासाठी ही जागा रिकामी सोडा.';
 $lang['updatecheck']           = 'अपडेट आणि सुरक्षिततेविशयी सूचनान्वर पाळत ठेऊ का? या सुविधेसाठी डॉक्युविकीला update.dokuwiki.org शी संपर्क साधावा लागेल.';
 $lang['userewrite']            = 'छान छान URL वापर';
 $lang['useslash']              = 'URL  मधे नेमस्पेस अलग करण्यासाठी \'/\' चिह्न वापरा';
@@ -133,12 +128,6 @@ $lang['proxy____port']         = 'छद्म ( proxy ) सर्वरचे 
 $lang['proxy____user']         = 'छद्म ( proxy ) सर्वरचे सदस्यनाम';
 $lang['proxy____pass']         = 'छद्म ( proxy ) सर्वरचा पासवर्ड';
 $lang['proxy____ssl']          = 'छद्म सर्वरला संपर्क साधण्यासाठी SSL वापरा';
-$lang['safemodehack']          = 'सेफमोड़ हॅक चालू करा';
-$lang['ftp____host']           = 'सेफमोड़ हॅक साठी FTP सर्वर';
-$lang['ftp____port']           = 'सेफमोड़ हॅक साठी FTP पोर्ट';
-$lang['ftp____user']           = 'सेफमोड़ हॅक साठी FTP सदस्यनाम';
-$lang['ftp____pass']           = 'सेफमोड़ हॅक साठी FTP पासवर्ड';
-$lang['ftp____root']           = 'सेफमोड़ हॅक साठी FTP मूळ डिरेक्टरी';
 $lang['license_o_']            = 'काही निवडले नाही';
 $lang['typography_o_0']        = 'काही नाही';
 $lang['typography_o_1']        = 'फक्त दुहेरी अवतरण चिह्न';
