@@ -1,14 +1,19 @@
 <?php
+
 /**
- * polish language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * @author Marek Adamski <fevbew@wp.pl>
+ * @author pavulondit <pavloo@vp.pl>
+ * @author Bartek S <sadupl@gmail.com>
+ * @author Wojciech Lichota <wojciech@lichota.pl>
+ * @author Max <maxrb146@gmail.com>
  * @author Grzegorz Żur <grzegorz.zur@gmail.com>
  * @author Mariusz Kujawski <marinespl@gmail.com>
  * @author Maciej Kurczewski <pipijajko@gmail.com>
  * @author Sławomir Boczek <slawkens@gmail.com>
  * @author Piotr JANKOWSKI <jankowski.piotr@gmail.com>
- * @author sleshek@wp.pl
+ * @author sleshek <sleshek@wp.pl>
  * @author Leszek Stachowski <shazarre@gmail.com>
  * @author maros <dobrimaros@yahoo.pl>
  * @author Grzegorz Widła <dzesdzes@gmail.com>
@@ -42,6 +47,7 @@ $lang['_advanced']             = 'Zaawansowane';
 $lang['_network']              = 'Sieć';
 $lang['_msg_setting_undefined'] = 'Brak danych o ustawieniu.';
 $lang['_msg_setting_no_class'] = 'Brak kategorii ustawień.';
+$lang['_msg_setting_no_known_class'] = 'Klasa ustawień niedostępna.';
 $lang['_msg_setting_no_default'] = 'Brak wartości domyślnej.';
 $lang['title']                 = 'Tytuł wiki';
 $lang['start']                 = 'Tytuł strony początkowej';
@@ -88,7 +94,9 @@ $lang['disableactions']        = 'Wyłącz akcje DokuWiki';
 $lang['disableactions_check']  = 'Sprawdzanie';
 $lang['disableactions_subscription'] = 'Subskrypcje';
 $lang['disableactions_wikicode'] = 'Pokazywanie źródeł';
+$lang['disableactions_profile_delete'] = 'Usuń własne konto ';
 $lang['disableactions_other']  = 'Inne akcje (oddzielone przecinkiem)';
+$lang['disableactions_rss']    = 'XML Syndication (RSS)';
 $lang['auth_security_timeout'] = 'Czas wygaśnięcia uwierzytelnienia (w sekundach)';
 $lang['securecookie']          = 'Czy ciasteczka wysłane do przeglądarki przez HTTPS powinny być przez nią odsyłane też tylko przez HTTPS? Odznacz tę opcję tylko wtedy, gdy logowanie użytkowników jest zabezpieczone SSL, ale przeglądanie stron odbywa się bez zabezpieczenia.';
 $lang['remote']                = 'Włącz API zdalnego dostępu. Pozwoli to innym aplikacjom na dostęp do wiki poprzez XML-RPC lub inne mechanizmy.';
@@ -119,15 +127,21 @@ $lang['subscribe_time']        = 'Czas po którym są wysyłane listy subskrypcj
 $lang['notify']                = 'Wysyłanie powiadomień na adres e-mail';
 $lang['registernotify']        = 'Prześlij informacje o nowych użytkownikach na adres e-mail';
 $lang['mailfrom']              = 'Adres e-mail tego wiki';
+$lang['mailreturnpath']        = 'Adres e-mail odbiorcy dla powiadomień o niedostarczeniu';
 $lang['mailprefix']            = 'Prefiks tematu e-mail do automatycznych wiadomości';
 $lang['htmlmail']              = 'Wysyłaj wiadomości e-mail w formacie HTML, które wyglądają lepiej, lecz ich rozmiar jest większy. Wyłącz wysyłanie wiadomości zawierających tekst niesformatowany.';
+$lang['dontlog']               = 'Wyłącz logowanie dla tego typu logów.';
 $lang['sitemap']               = 'Okres generowania Google Sitemap (w dniach)';
 $lang['rss_type']              = 'Typ RSS';
 $lang['rss_linkto']            = 'Odnośniki w RSS';
 $lang['rss_content']           = 'Rodzaj informacji wyświetlanych w RSS ';
 $lang['rss_update']            = 'Okres aktualizacji RSS (w sekundach)';
 $lang['rss_show_summary']      = 'Podsumowanie w tytule';
+$lang['rss_show_deleted']      = 'Pokaż usunięte kanały';
 $lang['rss_media']             = 'Rodzaj zmian wyświetlanych w RSS';
+$lang['rss_media_o_both']      = 'oba';
+$lang['rss_media_o_pages']     = 'strony';
+$lang['rss_media_o_media']     = 'media';
 $lang['updatecheck']           = 'Sprawdzanie aktualizacji i bezpieczeństwa. DokuWiki będzie kontaktować się z serwerem update.dokuwiki.org.';
 $lang['userewrite']            = 'Proste adresy URL';
 $lang['useslash']              = 'Używanie ukośnika jako separatora w adresie URL';
@@ -138,26 +152,33 @@ $lang['autoplural']            = 'Automatyczne tworzenie liczby mnogiej';
 $lang['compression']           = 'Metoda kompresji dla usuniętych plików';
 $lang['gzip_output']           = 'Używaj kodowania GZIP dla zawartości XHTML';
 $lang['compress']              = 'Kompresja arkuszy CSS i plików JavaScript';
-$lang['cssdatauri']            = 'Rozmiar w bajtach, poniżej którego odwołania do obrazów w plikach CSS powinny być osadzone bezpośrednio w arkuszu stylów by zmniejszyć ogólne żądania nagłówków HTTP. Technika ta nie działa w IE 7 i poniżej! <code>400</code> do <code>600</code> bajtów jest dobrą wartością. Ustaw <code>0</code> aby wyłączyć.';
+$lang['cssdatauri']            = 'Rozmiar w bajtach, poniżej którego odwołania do obrazów w plikach CSS powinny być osadzone bezpośrednio w arkuszu stylów by zmniejszyć ogólne żądania nagłówków HTTP. <code>400</code> do <code>600</code> bajtów jest dobrą wartością. Ustaw <code>0</code> aby wyłączyć.';
 $lang['send404']               = 'Nagłówek "HTTP 404/Page Not Found" dla nieistniejących stron';
 $lang['broken_iua']            = 'Czy funkcja "ignore_user_abort" działa? Jeśli nie, może to powodować problemy z indeksem przeszukiwania. Funkcja nie działa przy konfiguracji oprogramowania IIS+PHP/CGI. Szczegółowe informacje: <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>.';
 $lang['xsendfile']             = 'Użyj nagłówka HTTP X-Sendfile w celu przesyłania statycznych plików. Serwer HTTP musi obsługiwać ten nagłówek.';
 $lang['renderer_xhtml']        = 'Mechanizm renderowania głównej treści strony (xhtml)';
 $lang['renderer__core']        = '%s (dokuwiki)';
 $lang['renderer__plugin']      = '%s (wtyczka)';
+$lang['search_nslimit']        = 'Ogranicz wyszukiwanie do bieżących przestrzeni nazw X. Gdy wyszukiwanie jest wykonywane ze strony w głębszej przestrzeni nazw, pierwsze przestrzenie nazw X zostaną dodane jako filtr';
+$lang['search_fragment']       = 'Określ domyślne zachowanie wyszukiwania fragmentów';
+$lang['search_fragment_o_exact'] = 'dokładny';
+$lang['search_fragment_o_starts_with'] = 'zaczyna się z';
+$lang['search_fragment_o_ends_with'] = 'kończy się z';
+$lang['search_fragment_o_contains'] = 'zawiera';
+$lang['trustedproxy']          = 'Zaufaj serwerom proxy odpowiadającym temu wyrażeniu regularnemu co do prawdziwego adresu IP klienta, który zgłaszają. Domyślnie dotyczy sieci lokalnych. Pozostaw puste, aby nie ufać żadnym serwerom proxy.';
+$lang['_feature_flags']        = 'Flagi funkcji';
+$lang['defer_js']              = 'Odrocz wykonanie skryptu JavaScript po przeanalizowaniu kodu HTML strony. Poprawia postrzeganą szybkość strony, ale może zepsuć niewielką liczbę wtyczek.';
 $lang['dnslookups']            = 'DokiWiki wyszuka nazwy hostów dla zdalnych adresów IP użytkowników edytujących strony. Jeśli twój serwer DNS działa zbyt wolno, uległ awarii lub nie chcesz używać wyszukiwania, wyłącz tę opcję.';
+$lang['jquerycdn']             = 'Czy pliki skryptów jQuery i jQuery UI powinny być ładowane z CDN? Powoduje to dodanie dodatkowych żądań HTTP, ale pliki mogą być ładowane szybciej, a użytkownicy mogą już je mieć zbuforowane.';
+$lang['jquerycdn_o_0']         = 'Bez CDN, tylko lokalne zasoby';
+$lang['jquerycdn_o_jquery']    = 'CDN z code.jquery.com';
+$lang['jquerycdn_o_cdnjs']     = 'CDN z cdnjs.com';
 $lang['proxy____host']         = 'Proxy - serwer';
 $lang['proxy____port']         = 'Proxy - port';
 $lang['proxy____user']         = 'Proxy - nazwa użytkownika';
 $lang['proxy____pass']         = 'Proxy - hasło';
 $lang['proxy____ssl']          = 'Proxy - SSL';
 $lang['proxy____except']       = 'Wyrażenie regularne określające adresy URL, do których nie należy używać proxy.';
-$lang['safemodehack']          = 'Bezpieczny tryb (przez FTP)';
-$lang['ftp____host']           = 'FTP - serwer';
-$lang['ftp____port']           = 'FTP - port';
-$lang['ftp____user']           = 'FTP - nazwa użytkownika';
-$lang['ftp____pass']           = 'FTP - hasło';
-$lang['ftp____root']           = 'FTP - katalog główny';
 $lang['license_o_']            = 'Nie wybrano żadnej';
 $lang['typography_o_0']        = 'brak';
 $lang['typography_o_1']        = 'tylko podwójne cudzysłowy';
@@ -193,6 +214,7 @@ $lang['xsendfile_o_2']         = 'Standardowy nagłówek HTTP X-Sendfile';
 $lang['xsendfile_o_3']         = 'Specyficzny nagłówek Nginx X-Accel-Redirect';
 $lang['showuseras_o_loginname'] = 'Login użytkownika';
 $lang['showuseras_o_username'] = 'Pełne nazwisko użytkownika';
+$lang['showuseras_o_username_link'] = 'Imię i nazwisko użytkownika jako połączenie między wiki';
 $lang['showuseras_o_email']    = 'E-mail użytkownika (ukrywanie według ustawień mailguard)';
 $lang['showuseras_o_email_link'] = 'Adresy e-mail użytkowników w formie linku mailto:';
 $lang['useheading_o_0']        = 'Nigdy';
