@@ -2,15 +2,15 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Hamp Gábor <gabor.hamp@gmail.com>
  * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
  * @author Siaynoq Mage <siaynoqmage@gmail.com>
- * @author schilling.janos@gmail.com
+ * @author schilling.janos <schilling.janos@gmail.com>
  * @author Szabó Dávid <szabo.david@gyumolcstarhely.hu>
- * @author Sándor TIHANYI <stihanyi+dw@gmail.com>
- * @author David Szabo <szabo.david@gyumolcstarhely.hu>
  * @author Marton Sebok <sebokmarton@gmail.com>
  * @author Serenity87HUN <anikototh87@gmail.com>
+ * @author Marina Vladi <deldadam@gmail.com>
  */
 $lang['menu']                  = 'Felhasználók kezelése';
 $lang['noauth']                = '(A felhasználói azonosítás nem működik.)';
@@ -58,16 +58,18 @@ $lang['add_ok']                = 'A felhasználó sikeresen hozzáadva.';
 $lang['add_fail']              = 'A felhasználó hozzáadása nem sikerült.';
 $lang['notify_ok']             = 'Értesítő levél elküldve.';
 $lang['notify_fail']           = 'Nem sikerült az értesítő levelet elküldeni.';
-$lang['import_userlistcsv']    = 'Felhasználók listája fájl (CSV)';
+$lang['import_userlistcsv']    = 'Felhasználók listájának fájlja (CSV)';
 $lang['import_header']         = 'Legutóbbi importálás - Hibák';
 $lang['import_success_count']  = 'Felhasználók importálása: %d felhasználót találtunk, ebből %d sikeresen importálva.';
 $lang['import_failure_count']  = 'Felhasználók importálása: %d sikertelen. A sikertelenség okait lejjebb találod.';
 $lang['import_error_fields']   = 'Túl kevés mezőt adtál meg, %d darabot találtunk, legalább 4-re van szükség.';
 $lang['import_error_baduserid'] = 'Felhasználói azonosító hiányzik';
-$lang['import_error_badname']  = 'Nem megfelelő név';
-$lang['import_error_badmail']  = 'Nem megfelelő e-mailcím';
+$lang['import_error_badname']  = 'Helytelen név';
+$lang['import_error_badmail']  = 'Helytelen e-mailcím';
 $lang['import_error_upload']   = 'Sikertelen importálás. A csv fájl nem feltölthető vagy üres.';
 $lang['import_error_readfail'] = 'Sikertelen importálás. A feltöltött fájl nem olvasható.';
 $lang['import_error_create']   = 'Ez a felhasználó nem hozható létre';
 $lang['import_notify_fail']    = 'Az értesítő e-mail nem küldhető el az alábbi importált felhasználónak: %s e-mailcíme: %s.';
 $lang['import_downloadfailures'] = 'Töltsd le a hibákat tartalmazó fájlt CSV formátumban, hogy ki tudd javítani a hibákat';
+$lang['addUser_error_pass_not_identical'] = 'A begépelt jelszavak különböznek.';
+$lang['addUser_error_modPass_disabled'] = 'A jelszó megváltoztatása jelenleg nem lehetséges.';
