@@ -8,6 +8,7 @@
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Anika Henke <anika@selfthinker.org>
  */
+// phpcs:disable PSR1.Files.SideEffects
 if(!defined('DOKU_INC')) define('DOKU_INC',dirname(__FILE__).'/../../');
 if(!defined('NOSESSION')) define('NOSESSION',1);
 require_once(DOKU_INC.'inc/init.php');
@@ -17,7 +18,7 @@ require_once(DOKU_INC.'inc/init.php');
 <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
     <title>Template Replacements</title>
-    <style type="text/css">
+    <style>
         body {
             background-color: #fff;
             color: #000;
@@ -44,17 +45,16 @@ require_once(DOKU_INC.'inc/init.php');
 <body>
 <?php
 // get merged style.ini
-define('SIMPLE_TEST', true); // hack to prevent css output and headers
-require_once(DOKU_INC.'lib/exe/css.php');
-$ini = css_styleini($conf['template']);
+$styleUtils = new \dokuwiki\StyleUtils($conf['template']);
+$ini = $styleUtils->cssStyleini();
 
-if ($ini) {
+if (!empty($ini)) {
     echo '<table>';
-    echo "<caption>".htmlspecialchars($conf['template'])."'s style.ini</caption>";
+    echo "<caption>".hsc($conf['template'])."'s style.ini</caption>";
     foreach($ini['replacements'] as $key => $val){
         echo '<tr>';
-        echo '<td>'.htmlspecialchars($key).'</td>';
-        echo '<td>'.htmlspecialchars($val).'</td>';
+        echo '<td>'.hsc($key).'</td>';
+        echo '<td>'.hsc($val).'</td>';
         echo '<td>';
         if(preg_match('/^#[0-f]{3,6}$/i',$val)){
             echo '<div class="color" style="background-color:'.$val.';">&#160;</div>';
@@ -64,7 +64,7 @@ if ($ini) {
     }
     echo '</table>';
 } else {
-    echo "<p>Non-existent or invalid template or style.ini: <strong>".htmlspecialchars($conf['template'])."</strong></p>";
+    echo "<p>Non-existent or invalid template or style.ini: <strong>".hsc($conf['template'])."</strong></p>";
 }
 ?>
 </body>
